@@ -66,6 +66,10 @@ struct _BraseroTrackDataCfgPrivate
 	BraseroDataTreeModel *tree;
 	guint stamp;
 
+	/* allows some sort of caching */
+	GSList *grafts;
+	GSList *excluded;
+
 	guint loading;
 	guint loading_remaining;
 	GSList *load_errors;
@@ -115,8 +119,6 @@ typedef enum {
 enum {
 	AVAILABLE,
 	LOADED,
-	OVERSIZE,
-	ACTIVITY,
 	IMAGE,
 	UNREADABLE,
 	RECURSIVE,
@@ -359,6 +361,9 @@ brasero_track_data_cfg_iter_has_child (GtkTreeModel *model,
 	if (node->is_inserting)
 		return FALSE;
 
+	if (node->is_loading)
+		return FALSE;
+
 	if (node->is_file)
 		return FALSE;
 
@@ -1380,6 +1385,26 @@ brasero_track_data_cfg_autorun_inf_parse (BraseroTrackDataCfg *track,
 	return node;
 }
 
+static void
+brasero_track_data_cfg_clean_cache (BraseroTrackDataCfg *track)
+{
+	BraseroTrackDataCfgPrivate *priv;
+
+	priv = BRASERO_TRACK_DATA_CFG_PRIVATE (track);
+
+	if (priv->grafts) {
+		g_slist_foreach (priv->grafts, (GFunc) brasero_graft_point_free, NULL);
+		g_slist_free (priv->grafts);
+		priv->grafts = NULL;
+	}
+
+	if (priv->excluded) {
+		g_slist_foreach (priv->excluded, (GFunc) g_free, NULL);
+		g_slist_free (priv->excluded);
+		priv->excluded = NULL;
+	}
+}
+
 static void
 brasero_track_data_cfg_node_added (BraseroDataProject *project,
 				   BraseroFileNode *node,
@@ -1688,6 +1713,7 @@ brasero_track_data_cfg_finalize (GObject *object)
 	priv = BRASERO_TRACK_DATA_CFG_PRIVATE (object);
 
 	brasero_track_data_clean_autorun (BRASERO_TRACK_DATA_CFG (object));
+	brasero_track_data_cfg_clean_cache (BRASERO_TRACK_DATA_CFG (object));
 
 	if (priv->shown) {
 		g_slist_free (priv->shown);
@@ -1815,6 +1841,7 @@ brasero_track_data_cfg_add_empty_directory (BraseroTrackDataCfg *track,
 	BraseroTrackDataCfgPrivate *priv;
 	gchar *default_name = NULL;
 	BraseroFileNode *node;
+	GtkTreePath *path;
 
 	g_return_val_if_fail (BRASERO_TRACK_DATA_CFG (track), FALSE);
 
@@ -1852,7 +1879,11 @@ brasero_track_data_cfg_add_empty_directory (BraseroTrackDataCfg *track,
 	if (!node)
 		return NULL;
 
-	return brasero_track_data_cfg_node_to_path (track, node);
+	path = brasero_track_data_cfg_node_to_path (track, node);
+	if (path)
+		brasero_track_changed (BRASERO_TRACK (track));
+
+	return path;
 }
 
 gboolean
@@ -1921,6 +1952,10 @@ brasero_track_data_cfg_reset (BraseroTrackDataCfg *track)
 	priv->G2_files = FALSE;
 	priv->deep_directory = FALSE;
 	priv->joliet_rename = FALSE;
+
+	brasero_track_data_cfg_clean_cache (track);
+
+	brasero_track_changed (BRASERO_TRACK (track));
 	return TRUE;
 }
 
@@ -2137,39 +2172,43 @@ brasero_track_data_cfg_get_grafts (BraseroTrackData *track)
 {
 	BraseroTrackDataCfgPrivate *priv;
 	BraseroImageFS fs_type;
-	GSList *grafts = NULL;
 
 	priv = BRASERO_TRACK_DATA_CFG_PRIVATE (track);
 
+	if (priv->grafts)
+		return priv->grafts;
+
 	/* append a slash for mkisofs */
 	fs_type = brasero_track_data_cfg_get_fs (track);
 	brasero_data_project_get_contents (BRASERO_DATA_PROJECT (priv->tree),
-					   &grafts,
-					   NULL,
+					   &priv->grafts,
+					   &priv->excluded,
 					   TRUE, /* include hidden nodes */
 					   (fs_type & BRASERO_IMAGE_FS_JOLIET) != 0,
 					   TRUE);
-	return grafts;
+	return priv->grafts;
 }
 
 static GSList *
 brasero_track_data_cfg_get_excluded (BraseroTrackData *track)
 {
 	BraseroTrackDataCfgPrivate *priv;
-	GSList *unreadable = NULL;
 	BraseroImageFS fs_type;
 
 	priv = BRASERO_TRACK_DATA_CFG_PRIVATE (track);
 
+	if (priv->excluded)
+		return priv->excluded;
+
 	/* append a slash for mkisofs */
 	fs_type = brasero_track_data_cfg_get_fs (track);
 	brasero_data_project_get_contents (BRASERO_DATA_PROJECT (priv->tree),
-					   NULL,
-					   &unreadable,
+					   &priv->grafts,
+					   &priv->excluded,
 					   TRUE, /* include hidden nodes */
 					   (fs_type & BRASERO_IMAGE_FS_JOLIET) != 0,
 					   TRUE);
-	return unreadable;
+	return priv->excluded;
 }
 
 static guint64
@@ -2237,8 +2276,15 @@ brasero_track_data_cfg_get_status (BraseroTrack *track,
 		return BRASERO_BURN_ERR;
 	}
 
-	if (brasero_data_project_is_empty (BRASERO_DATA_PROJECT (priv->tree)))
+	if (brasero_data_session_get_loaded_medium (BRASERO_DATA_SESSION (priv->tree)) == NULL
+	&& brasero_data_project_is_empty (BRASERO_DATA_PROJECT (priv->tree))) {
+		if (status)
+			brasero_status_set_error (status,
+						  g_error_new (BRASERO_BURN_ERROR,
+						               BRASERO_BURN_ERROR_EMPTY,
+						               _("There are no files to write to disc")));
 		return BRASERO_BURN_ERR;
+	}
 
 	return BRASERO_BURN_OK;
 }
@@ -2356,7 +2402,7 @@ brasero_track_data_cfg_recursive_uri_cb (BraseroDataVFS *vfs,
 		gchar *name;
 
 		name = brasero_utils_get_uri_name (uri);
-		message = g_strdup_printf (_("\"%s\" is a recursive symlink."), name);
+		message = g_strdup_printf (_("\"%s\" is a recursive symbolic link."), name);
 		priv->load_errors = g_slist_prepend (priv->load_errors, message);
 		g_free (name);
 
@@ -2679,31 +2725,16 @@ brasero_track_data_cfg_activity_changed (BraseroDataVFS *vfs,
 
 emit_signal:
 
-	g_signal_emit (self,
-		       brasero_track_data_cfg_signals [ACTIVITY],
-		       0,
-		       active);
+	brasero_track_data_cfg_clean_cache (self);
 
 	brasero_track_changed (BRASERO_TRACK (self));
 }
 
-static void
-brasero_track_data_cfg_oversized_cb (BraseroDataProject *project,
-				     gboolean is_oversized,
-				     gboolean overburn_possible,
-				     BraseroTrackDataCfg *self)
-{
-	g_signal_emit (self,
-		       brasero_track_data_cfg_signals [OVERSIZE],
-		       0,
-		       is_oversized,
-		       overburn_possible);
-}
-
 static void
 brasero_track_data_cfg_size_changed_cb (BraseroDataProject *project,
 					BraseroTrackDataCfg *self)
 {
+	brasero_track_data_cfg_clean_cache (self);
 	brasero_track_changed (BRASERO_TRACK (self));
 }
 
@@ -2731,6 +2762,8 @@ brasero_track_data_cfg_session_loaded_cb (BraseroDataSession *session,
 		       0,
 		       medium,
 		       loaded);
+
+	brasero_track_changed (BRASERO_TRACK (self));
 }
 
 BraseroBurnResult
@@ -2797,26 +2830,6 @@ brasero_track_data_cfg_span_stop (BraseroTrackDataCfg *track)
  * This is to handle the icon for the image
  */
 
-gchar *
-brasero_track_data_cfg_get_scaled_icon_path (BraseroTrackDataCfg *track)
-{
-	BraseroTrackDataCfgPrivate *priv;
-	gchar *path;
-	gchar *uri;
-
-	g_return_val_if_fail (BRASERO_IS_TRACK_DATA_CFG (track), NULL);
-
-	priv = BRASERO_TRACK_DATA_CFG_PRIVATE (track);
-	if (!priv->icon || BRASERO_FILE_NODE_VIRTUAL (priv->icon))
-		return NULL;
-
-	uri = brasero_data_project_node_to_uri (BRASERO_DATA_PROJECT (priv->tree), priv->icon);
-	path = g_filename_from_uri (uri, NULL, NULL);
-	g_free (uri);
-
-	return path;
-}
-
 const gchar *
 brasero_track_data_cfg_get_icon_path (BraseroTrackDataCfg *track)
 {
@@ -2828,6 +2841,25 @@ brasero_track_data_cfg_get_icon_path (BraseroTrackDataCfg *track)
 	return priv->image_path;
 }
 
+static gchar *
+brasero_track_data_cfg_get_scaled_icon_path (BraseroTrackDataCfg *track)
+{
+	BraseroTrackDataCfgPrivate *priv;
+	gchar *path;
+	gchar *uri;
+
+	g_return_val_if_fail (BRASERO_IS_TRACK_DATA_CFG (track), NULL);
+	priv = BRASERO_TRACK_DATA_CFG_PRIVATE (track);
+	if (!priv->icon || BRASERO_FILE_NODE_VIRTUAL (priv->icon))
+		return NULL;
+
+	uri = brasero_data_project_node_to_uri (BRASERO_DATA_PROJECT (priv->tree), priv->icon);
+	path = g_filename_from_uri (uri, NULL, NULL);
+	g_free (uri);
+
+	return path;
+}
+
 gboolean
 brasero_track_data_cfg_set_icon (BraseroTrackDataCfg *track,
 				 const gchar *icon_path,
@@ -2952,6 +2984,8 @@ brasero_track_data_cfg_set_icon (BraseroTrackDataCfg *track,
 
 		/* Add it as a graft to the project */
 		uri = g_filename_to_uri (path, NULL, NULL);
+		g_free (path);
+
 		priv->autorun = brasero_data_project_add_hidden_node (BRASERO_DATA_PROJECT (priv->tree),
 								      uri,
 								      "autorun.inf",
@@ -3001,10 +3035,6 @@ brasero_track_data_cfg_init (BraseroTrackDataCfg *object)
 			  G_CALLBACK (brasero_track_data_cfg_node_reordered),
 			  object);
 
-	g_signal_connect (priv->tree,
-			  "oversize",
-			  G_CALLBACK (brasero_track_data_cfg_oversized_cb),
-			  object);
 	g_signal_connect (priv->tree,
 			  "size-changed",
 			  G_CALLBACK (brasero_track_data_cfg_size_changed_cb),
@@ -3111,28 +3141,6 @@ brasero_track_data_cfg_class_init (BraseroTrackDataCfgClass *klass)
 			  2,
 			  G_TYPE_OBJECT,
 			  G_TYPE_BOOLEAN);
-	brasero_track_data_cfg_signals [OVERSIZE] = 
-	    g_signal_new ("session_oversized",
-			  G_TYPE_FROM_CLASS (klass),
-			  G_SIGNAL_RUN_LAST,
-			  0,
-			  NULL, NULL,
-			  brasero_marshal_VOID__BOOLEAN_BOOLEAN,
-			  G_TYPE_NONE,
-			  2,
-			  G_TYPE_BOOLEAN,
-			  G_TYPE_BOOLEAN);
-
-	brasero_track_data_cfg_signals [ACTIVITY] = 
-	    g_signal_new ("vfs_activity",
-			  G_TYPE_FROM_CLASS (klass),
-			  G_SIGNAL_RUN_FIRST|G_SIGNAL_NO_RECURSE,
-			  0,
-			  NULL, NULL,
-			  g_cclosure_marshal_VOID__BOOLEAN,
-			  G_TYPE_NONE,
-			  1,
-			  G_TYPE_BOOLEAN);
 
 	brasero_track_data_cfg_signals [IMAGE] = 
 	    g_signal_new ("image_uri",
