@@ -411,7 +411,6 @@ brasero_job_check_output_disc_space (BraseroJob *self,
 	/* This is not really an error, we'll probably ask the 
 	 * user to load a new disc */
 	if (output_blocks > media_blocks) {
-		gchar *available_str;
 		gchar *media_blocks_str;
 		gchar *output_blocks_str;
 
@@ -420,25 +419,20 @@ brasero_job_check_output_disc_space (BraseroJob *self,
 				  output_blocks);
 
 		media_blocks_str = g_strdup_printf ("%"G_GINT64_FORMAT, media_blocks);
-		output_blocks_str = g_strdup_printf ("%" G_GINT64_FORMAT, output_blocks);
-
-		/* Translators: the first %s is the size of the free space on the medium
-		 * and the second %s is the size of the space required by the data to be
-		 * burnt. */
-		available_str = g_strdup_printf (_("(%s available for %s)"),
-						 media_blocks_str,
-						 output_blocks_str);
-		g_free (media_blocks_str);
-		g_free (output_blocks_str);
+		output_blocks_str = g_strdup_printf ("%"G_GINT64_FORMAT, output_blocks);
 
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_MEDIUM_SPACE,
-			     "%s %s.",
-			     _("Not enough space available on the disc"),
-			     available_str);
+			     /* Translators: the first %s is the size of the free space on the medium
+			      * and the second %s is the size of the space required by the data to be
+			      * burnt. */
+			     _("Not enough space available on the disc (%s available for %s)"),
+			     media_blocks_str,
+			     output_blocks_str);
 
-		g_free (available_str);
+		g_free (media_blocks_str);
+		g_free (output_blocks_str);
 		return BRASERO_BURN_NEED_RELOAD;
 	}
 
@@ -618,8 +612,7 @@ brasero_job_set_output_file (BraseroJob *self,
 
 			result = brasero_burn_session_get_output (session,
 								  &image,
-								  &toc,
-								  error);
+								  &toc);
 
 			/* check paths are set */
 			if (!image
@@ -1475,26 +1468,6 @@ brasero_job_get_action (BraseroJob *self, BraseroJobAction *action)
 	return BRASERO_BURN_OK;
 }
 
-BraseroBurnResult
-brasero_job_get_bus_target_lun (BraseroJob *self, gchar **BTL)
-{
-	BraseroBurnSession *session;
-	BraseroJobPrivate *priv;
-	BraseroDrive *drive;
-
-	BRASERO_JOB_DEBUG (self);
-
-	g_return_val_if_fail (BTL != NULL, BRASERO_BURN_ERR);
-
-	priv = BRASERO_JOB_PRIVATE (self);
-	session = brasero_task_ctx_get_session (priv->ctx);
-
-	drive = brasero_burn_session_get_burner (session);
-	*BTL = brasero_drive_get_bus_target_lun_string (drive);;
-
-	return BRASERO_BURN_OK;
-}
-
 BraseroBurnResult
 brasero_job_get_device (BraseroJob *self, gchar **device)
 {
@@ -1897,8 +1870,8 @@ brasero_job_set_rate (BraseroJob *self,
 
 BraseroBurnResult
 brasero_job_set_output_size_for_current_track (BraseroJob *self,
-					       gint64 sectors,
-					       gint64 size)
+					       goffset sectors,
+					       goffset bytes)
 {
 	BraseroJobPrivate *priv;
 
@@ -1918,12 +1891,12 @@ brasero_job_set_output_size_for_current_track (BraseroJob *self,
 
 	return brasero_task_ctx_set_output_size_for_current_track (priv->ctx,
 								   sectors,
-								   size);
+								   bytes);
 }
 
 BraseroBurnResult
 brasero_job_set_written_track (BraseroJob *self,
-			       gint64 written)
+			       goffset written)
 {
 	BraseroJobPrivate *priv;
 
@@ -1939,7 +1912,7 @@ brasero_job_set_written_track (BraseroJob *self,
 
 BraseroBurnResult
 brasero_job_set_written_session (BraseroJob *self,
-				 gint64 written)
+				 goffset written)
 {
 	BraseroJobPrivate *priv;
 
