@@ -39,7 +39,6 @@
 
 #include "brasero-burn-lib.h"
 #include "brasero-track.h"
-#include "brasero-data-options.h"
 #include "brasero-track-data-cfg.h"
 #include "brasero-track-image-cfg.h"
 #include "brasero-track-disc.h"
@@ -186,7 +185,7 @@ nautilus_disc_burn_is_empty (GtkWindow *toplevel)
 
 		brasero_utils_message_dialog (GTK_WIDGET (toplevel),
 					      _("Please add files."),
-					      _("The project is empty"),
+					      _("There are no files to write to disc"),
 					      GTK_MESSAGE_ERROR);
 		return TRUE;
 	}
@@ -202,7 +201,6 @@ write_activate (GtkWindow *toplevel)
 	BraseroSessionCfg	*session;
 	GtkWidget 		*name_options;
 	GtkWidget		*options;
-	GtkWidget	        *box;
 	gchar			*string;
 
 	if (nautilus_disc_burn_is_empty (toplevel))
@@ -213,17 +211,14 @@ write_activate (GtkWindow *toplevel)
 
 	session = brasero_session_cfg_new ();
 	brasero_burn_session_add_track (BRASERO_BURN_SESSION (session),
-					BRASERO_TRACK (track));
+					BRASERO_TRACK (track),
+					NULL);
 	g_object_unref (track);
 
-	/* Add option widget */
-	box = gtk_vbox_new (FALSE, 6);
-	gtk_widget_show (box);
-
 	/* add name widget here to set the label of the volume */
-	name_options = brasero_project_name_new ();
-	brasero_project_name_set_type (BRASERO_PROJECT_NAME (name_options),
-				       BRASERO_PROJECT_TYPE_DATA);
+	name_options = brasero_project_name_new (NULL);
+	brasero_project_name_set_session (BRASERO_PROJECT_NAME (name_options),
+					  BRASERO_BURN_SESSION (session));
 
 	string = g_strdup_printf ("<b>%s</b>", _("Disc name"));
 	options = brasero_utils_pack_properties (string,
@@ -231,16 +226,9 @@ write_activate (GtkWindow *toplevel)
 						 NULL);
 	g_free (string);
 	gtk_widget_show_all (options);
-	gtk_box_pack_start (GTK_BOX (box), options, FALSE, TRUE, 0);
-
-	/* create the options box */
-	options = brasero_data_options_new (BRASERO_BURN_SESSION (session));
-	gtk_widget_show (options);
-	gtk_box_pack_start (GTK_BOX (box), options, FALSE, TRUE, 0);
 
 	/* NOTE: set the disc we're handling */
 	launch_brasero_on_window_session (session, options, toplevel);
-	g_object_unref (session);
 
 	/* cleanup */
 	g_object_unref (session);
@@ -263,7 +251,8 @@ launch_brasero_on_window_track (BraseroTrack	*track,
 	/* create a session and add track */
 	session = brasero_session_cfg_new ();
 	brasero_burn_session_add_track (BRASERO_BURN_SESSION (session),
-					BRASERO_TRACK (track));
+					BRASERO_TRACK (track),
+					NULL);
 
 	launch_brasero_on_window_session (session, options, window);
 	g_object_unref (session);
@@ -945,7 +934,7 @@ nautilus_module_initialize (GTypeModule *module)
         DEBUG_PRINT ("Initializing nautilus-disc-recorder\n");
 
         brasero_media_library_start ();
-        brasero_burn_library_start ();
+        brasero_burn_library_start (NULL, NULL);
         DEBUG_PRINT ("Libbrasero-media started\n");
 
         nautilus_disc_burn_register_type (module);
