@@ -1,22 +1,28 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /*
- * brasero-vob.c
- * Copyright (C) Rouquier Philippe 2008 <bonfire-app@wanadoo.fr>
+ * Libbrasero-burn
+ * Copyright (C) Philippe Rouquier 2005-2009 <bonfire-app@wanadoo.fr>
+ *
+ * Libbrasero-burn is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * The Libbrasero-burn authors hereby grant permission for non-GPL compatible
+ * GStreamer plugins to be used and distributed together with GStreamer
+ * and Libbrasero-burn. This permission is above and beyond the permissions granted
+ * by the GPL license by which Libbrasero-burn is covered. If you modify this code
+ * you may extend this exception to your version of the code, but you are not
+ * obligated to do so. If you do not wish to do so, delete this exception
+ * statement from your version.
  * 
- * brasero-vob.c is free software.
- * 
- * You may redistribute it and/or modify it under the terms of the
- * GNU General Public License, as published by the Free Software
- * Foundation; either version 2 of the License, or (at your option)
- * any later version.
- * 
- * brasero-vob.c is distributed in the hope that it will be useful,
+ * Libbrasero-burn is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * See the GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Library General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with brasero-vob.c.  If not, write to:
+ * along with this program; if not, write to:
  * 	The Free Software Foundation, Inc.,
  * 	51 Franklin Street, Fifth Floor
  * 	Boston, MA  02110-1301, USA.
@@ -1131,12 +1137,20 @@ brasero_vob_clock_tick (BraseroJob *job)
 	gst_element_query_duration (priv->pipeline, &format, &duration);
 	gst_element_query_position (priv->pipeline, &format, &position);
 
-	if (duration > 0.0) {
+	if (duration <= 0.0 || position <= 0.0) {
+		format = GST_FORMAT_BYTES;
+		gst_element_query_duration (priv->pipeline, &format, &duration);
+		gst_element_query_position (priv->pipeline, &format, &position);
+	}
+
+	if (duration > 0.0 && position > 0.0) {
 		gdouble progress;
 
 		progress = (gdouble) position / (gdouble) duration;
 		brasero_job_set_progress (job, progress);
 	}
+	else
+		brasero_job_set_progress (job, -1.0);
 
 	return BRASERO_BURN_OK;
 }
