@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /*
- * brasero
- * Copyright (C) Philippe Rouquier 2007-2008 <bonfire-app@wanadoo.fr>
+ * Brasero
+ * Copyright (C) Philippe Rouquier 2005-2009 <bonfire-app@wanadoo.fr>
  * 
  *  Brasero is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -52,6 +52,7 @@
 
 #include "burn-basics.h"
 
+#include "brasero-session-cfg.h"
 #include "brasero-tags.h"
 #include "brasero-track.h"
 #include "brasero-track-data.h"
@@ -67,7 +68,8 @@ struct _BraseroDataDiscPrivate
 	GtkWidget *tree;
 	GtkWidget *filter;
 	BraseroTrackDataCfg *project;
-	GtkWidget *notebook;
+
+	GtkSizeGroup *button_size;
 
 	GtkWidget *message;
 
@@ -90,13 +92,20 @@ struct _BraseroDataDiscPrivate
 	guint overburning:1;
 
 	guint loading:1;
+
+	guint never_replace:1;
+	guint always_replace:1;
+	guint accept_2G_files:1;
+	guint reject_2G_files:1;
+	guint accept_deep_files:1;
+	guint reject_deep_files:1;
 };
 
 #define BRASERO_DATA_DISC_PRIVATE(o)  (G_TYPE_INSTANCE_GET_PRIVATE ((o), BRASERO_TYPE_DATA_DISC, BraseroDataDiscPrivate))
 
 
 static void
-brasero_data_disc_new_folder_clicked_cb (GtkButton *button,
+brasero_data_disc_new_folder_clicked_cb (GtkAction *action,
 					 BraseroDataDisc *disc);
 static void
 brasero_data_disc_open_activated_cb (GtkAction *action,
@@ -167,13 +176,6 @@ static GtkTargetEntry ntables_source [] = {
 
 static guint nb_targets_source = sizeof (ntables_source) / sizeof (ntables_source[0]);
 
-enum {
-	ICON_CHANGED, 
-	LAST_SIGNAL
-};
-
-static gulong brasero_data_disc_signals [LAST_SIGNAL] = { 0 };
-
 enum {
 	PROP_NONE,
 	PROP_REJECT_FILE,
@@ -231,7 +233,6 @@ brasero_data_disc_import_session (BraseroDataDisc *disc,
 			return FALSE;
 		}
 
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook), 1);
 		return TRUE;
 	}
 
@@ -285,7 +286,7 @@ brasero_data_disc_get_parent (BraseroDataDisc *self)
 	if (g_list_length (list) != 1) {
 		g_list_foreach (list, (GFunc) gtk_tree_path_free, NULL);
 		g_list_free (list);
-		return gtk_tree_path_new_first ();
+		return NULL;
 	}
 
 	treepath = list->data;
@@ -315,7 +316,7 @@ brasero_data_disc_get_parent (BraseroDataDisc *self)
 }
 
 static void
-brasero_data_disc_new_folder_clicked_cb (GtkButton *button,
+brasero_data_disc_new_folder_clicked_cb (GtkAction *action,
 					 BraseroDataDisc *disc)
 {
 	BraseroDataDiscPrivate *priv;
@@ -331,8 +332,6 @@ brasero_data_disc_new_folder_clicked_cb (GtkButton *button,
 	treepath = brasero_track_data_cfg_add_empty_directory (BRASERO_TRACK_DATA_CFG (priv->project), NULL, parent);
 	gtk_tree_path_free (parent);
 
-	gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook), 1);
-
 	/* grab focus must be called before next function to avoid
 	 * triggering a bug where if pointer is not in the widget 
 	 * any more and enter is pressed the cell will remain editable */
@@ -437,8 +436,6 @@ brasero_data_disc_paste_activated_cb (GtkAction *action,
 	data = g_new0 (BraseroClipData, 1);
 	data->disc = disc;
 
-	gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook), 1);
-
 	parent = brasero_data_disc_get_parent (disc);
 	if (parent)
 		data->reference = gtk_tree_row_reference_new (GTK_TREE_MODEL (priv->project), parent);
@@ -522,79 +519,6 @@ brasero_data_disc_name_edited_cb (GtkCellRendererText *cellrenderertext,
  * miscellaneous callbacks
  */
 
-static void
-brasero_data_disc_use_overburn_response_cb (BraseroDiscMessage *message,
-					    GtkResponseType response,
-					    BraseroDataDisc *self)
-{
-	BraseroDataDiscPrivate *priv;
-
-	priv = BRASERO_DATA_DISC_PRIVATE (self);
-
-	if (response != GTK_RESPONSE_OK)
-		return;
-
-	priv->overburning = 1;
-}
-
-static void
-brasero_data_disc_project_oversized_cb (BraseroTrackDataCfg *project,
-					gboolean oversized,
-					gboolean overburn,
-					BraseroDataDisc *self)
-{
-	GtkWidget *message;
-	BraseroDataDiscPrivate *priv;
-
-	priv = BRASERO_DATA_DISC_PRIVATE (self);
-
-	if (!priv->message)
-		return;
-
-	if (overburn) {
-		if (priv->overburning)
-			return;
-
-		message = brasero_notify_message_add (BRASERO_NOTIFY (priv->message),
-						      _("Would you like to burn beyond the disc reported capacity?"),
-						      _("The size of the project is too large for the disc and you must remove files from the project otherwise."
-							"\nYou may want to use this option if you're using 90 or 100 min CD-R(W) which cannot be properly recognised and therefore need overburn option."
-							"\nNOTE: This option might cause failure."),
-						      -1,
-						      BRASERO_NOTIFY_CONTEXT_SIZE);
-
-		brasero_disc_message_set_image (BRASERO_DISC_MESSAGE (message), GTK_STOCK_DIALOG_WARNING);
-		brasero_notify_button_add (BRASERO_NOTIFY (priv->message),
-					   BRASERO_DISC_MESSAGE (message),
-					   _("_Overburn"),
-					   _("Burn beyond the disc reported capacity"),
-					   GTK_RESPONSE_OK);
-		brasero_notify_button_add (BRASERO_NOTIFY (priv->message),
-					   BRASERO_DISC_MESSAGE (message),
-					   GTK_STOCK_CANCEL,
-					   _("Click here not to use overburning"),
-					   GTK_RESPONSE_CANCEL);
-		
-		g_signal_connect (BRASERO_DISC_MESSAGE (message),
-				  "response",
-				  G_CALLBACK (brasero_data_disc_use_overburn_response_cb),
-				  self);
-	}
-	else if (oversized) {
-		message = brasero_notify_message_add (BRASERO_NOTIFY (priv->message),
-						      _("Please delete some files from the project."),
-						      _("The size of the project is too large for the disc even with the overburn option."),
-						      -1,
-						      BRASERO_NOTIFY_CONTEXT_SIZE);
-
-		brasero_disc_message_set_image (BRASERO_DISC_MESSAGE (message), GTK_STOCK_DIALOG_WARNING);
-		brasero_disc_message_add_close_button (BRASERO_DISC_MESSAGE (message));
-	}
-	else
-		brasero_notify_message_remove (BRASERO_NOTIFY (priv->message),
-					       BRASERO_NOTIFY_CONTEXT_SIZE);
-}
-
 static void
 brasero_data_disc_project_loading_cb (BraseroTrackDataCfg *project,
 				      gdouble progress,
@@ -664,29 +588,6 @@ brasero_data_disc_project_loaded_cb (BraseroTrackDataCfg *project,
 	}
 }
 
-static void
-brasero_data_disc_activity_changed_cb (BraseroTrackDataCfg *vfs,
-				       gboolean active,
-				       BraseroDataDisc *self)
-{
-	BraseroDataDiscPrivate *priv;
-
-	priv = BRASERO_DATA_DISC_PRIVATE (self);
-
-	if (!GTK_WIDGET (self)->window)
-		return;
-
-	if (active) {
-		GdkCursor *cursor;
-
-		cursor = gdk_cursor_new (GDK_WATCH);
-		gdk_window_set_cursor (GTK_WIDGET (self)->window, cursor);
-		gdk_cursor_unref (cursor);
-	}
-	else
-		gdk_window_set_cursor (GTK_WIDGET (self)->window, NULL);
-}
-
 static BraseroBurnResult
 brasero_data_disc_image_uri_cb (BraseroTrackDataCfg *vfs,
 				const gchar *uri,
@@ -702,22 +603,22 @@ brasero_data_disc_image_uri_cb (BraseroTrackDataCfg *vfs,
 
 	priv = BRASERO_DATA_DISC_PRIVATE (self);
 
-	name = brasero_utils_get_uri_name (uri);
-	string = g_strdup_printf (_("Do you want to burn \"%s\" to a disc or add it in to the data project?"), name);
 	dialog = brasero_app_dialog (brasero_app_get_default (),
-				     string,
-				     GTK_BUTTONS_NONE,
-				     GTK_MESSAGE_QUESTION);
+	                             _("Do you want to create a disc from the contents of the image or with the image file inside?"),
+	                             GTK_BUTTONS_NONE,
+	                             GTK_MESSAGE_QUESTION);
+
+	name = brasero_utils_get_uri_name (uri);
+	/* Translators: %s is the name of the image */
+	string = g_strdup_printf (_("There is only one selected file (\"%s\"). It is the image of a disc and its contents can be burnt."), name);
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), string);
 	g_free (string);
 	g_free (name);
 
-	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-						  _("This file is the image of a disc and can therefore be burnt to disc without having to add it to a data project first."));
+	gtk_dialog_add_button (GTK_DIALOG (dialog), _("Burn as _File"), GTK_RESPONSE_NO);
 
-	gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Add to Project"), GTK_RESPONSE_NO);
-
-	button = brasero_utils_make_button (_("_Burn..."),
-					    NULL,
+	button = brasero_utils_make_button (_("Burn _Contents..."),
+	                                    NULL,
 					    "media-optical-burn",
 					    GTK_ICON_SIZE_BUTTON);
 	gtk_widget_show (button);
@@ -836,7 +737,7 @@ brasero_data_disc_joliet_rename_cb (BraseroTrackDataCfg *project,
 	secondary = g_strdup_printf ("%s\n%s",
 				     _("Some files don't have a suitable name for a fully Windows-compatible CD."),
 				     _("Those names should be changed and truncated to 64 characters."));
-	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), secondary);
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), "%s", secondary);
 	g_free (secondary);
 
 	gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Rename for Full Windows Compatibility"), GTK_RESPONSE_YES);
@@ -866,6 +767,13 @@ brasero_data_disc_name_collision_cb (BraseroTrackDataCfg *project,
 
 	priv = BRASERO_DATA_DISC_PRIVATE (self);
 
+	if (priv->always_replace)
+		return TRUE;
+
+	if (priv->never_replace)
+		return FALSE;
+
+	/* Translators: %s is the name of the file */
 	string = g_strdup_printf (_("Do you really want to replace \"%s\"?"), name);
 	dialog = brasero_app_dialog (brasero_app_get_default (),
 				     string,
@@ -874,18 +782,33 @@ brasero_data_disc_name_collision_cb (BraseroTrackDataCfg *project,
 	g_free (string);
 
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-						  _("It already exists in the directory."));
+						  _("A file with the same name is about to be added into the same directory and will replace it if you accept."));
 
 	/* Translators: Keep means we're keeping the files that already existed
-	 * Replace means we're replacing it with a new one with the same name */
-	gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Keep Project File"), GTK_RESPONSE_NO);
-	gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Replace Project File"), GTK_RESPONSE_YES);
+	 * in the project.
+	 * Keep is a verb */
+	gtk_dialog_add_button (GTK_DIALOG (dialog), _("Always K_eep"), GTK_RESPONSE_REJECT);
+	/* Translators: Keep means we're keeping the files that already existed
+	 * in the project.
+	 * Keep is a verb */
+	gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Keep"), GTK_RESPONSE_NO);
+	/* Translators: Replace means we're replacing the file that already
+	 * existed in the project with a new one with the same name.
+	 * Replace is a verb */
+	gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Replace"), GTK_RESPONSE_YES);
+	/* Translators: Replace means we're replacing the file that already
+	 * existed in the project with a new one with the same name.
+	 * Replace is a verb */
+	gtk_dialog_add_button (GTK_DIALOG (dialog), _("Al_ways Replace"), GTK_RESPONSE_ACCEPT);
 
 	gtk_widget_show_all (dialog);
 	answer = gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 
-	return (answer != GTK_RESPONSE_YES);
+	priv->always_replace = (answer == GTK_RESPONSE_ACCEPT);
+	priv->never_replace = (answer == GTK_RESPONSE_REJECT);
+
+	return (answer != GTK_RESPONSE_YES && answer != GTK_RESPONSE_ACCEPT);
 }
 
 static gboolean
@@ -900,6 +823,12 @@ brasero_data_disc_2G_file_cb (BraseroTrackDataCfg *project,
 
 	priv = BRASERO_DATA_DISC_PRIVATE (self);
 
+	if (priv->accept_deep_files)
+		return TRUE;
+
+	if (priv->reject_deep_files)
+		return FALSE;
+
 	string = g_strdup_printf (_("Do you really want to add \"%s\" to the selection and use the third version of ISO9660 standard to support it?"), name);
 	dialog = brasero_app_dialog (brasero_app_get_default (),
 				     string,
@@ -912,14 +841,19 @@ brasero_data_disc_2G_file_cb (BraseroTrackDataCfg *project,
 						    "\nIt is recommended to use the third version of ISO9660 standard which is supported by most of the operating systems including Linux and all versions of Windows ©."
 						    "\nHowever MacOS X cannot read images created with version 3 of ISO9660 standard."));
 
+	gtk_dialog_add_button (GTK_DIALOG (dialog), _("Ne_ver Add Such File"), GTK_RESPONSE_REJECT);
 	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_NO);
 	gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Add File"), GTK_RESPONSE_YES);
+	gtk_dialog_add_button (GTK_DIALOG (dialog), _("Al_ways Add Such File"), GTK_RESPONSE_ACCEPT);
 
 	gtk_widget_show_all (dialog);
 	answer = gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 
-	return (answer != GTK_RESPONSE_YES);
+	priv->accept_deep_files = (answer == GTK_RESPONSE_ACCEPT);
+	priv->reject_deep_files = (answer == GTK_RESPONSE_REJECT);
+
+	return (answer != GTK_RESPONSE_YES && answer != GTK_RESPONSE_ACCEPT);
 }
 
 static gboolean
@@ -934,6 +868,12 @@ brasero_data_disc_deep_directory_cb (BraseroTrackDataCfg *project,
 
 	priv = BRASERO_DATA_DISC_PRIVATE (self);
 
+	if (priv->accept_2G_files)
+		return TRUE;
+
+	if (priv->reject_2G_files)
+		return FALSE;
+
 	string = g_strdup_printf (_("Do you really want to add \"%s\" to the selection?"), name);
 	dialog = brasero_app_dialog (brasero_app_get_default (),
 				     string,
@@ -946,14 +886,19 @@ brasero_data_disc_deep_directory_cb (BraseroTrackDataCfg *project,
 						    "\nBrasero can create an image of such a file hierarchy and burn it; but the disc may not be readable on all operating systems."
 						    "\nNOTE: Such a file hierarchy is known to work on linux."));
 
+	gtk_dialog_add_button (GTK_DIALOG (dialog), _("Ne_ver Add Such File"), GTK_RESPONSE_REJECT);
 	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_NO);
 	gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Add File"), GTK_RESPONSE_YES);
+	gtk_dialog_add_button (GTK_DIALOG (dialog), _("Al_ways Add Such File"), GTK_RESPONSE_ACCEPT);
 
 	gtk_widget_show_all (dialog);
 	answer = gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 
-	return (answer != GTK_RESPONSE_YES);
+	priv->accept_2G_files = (answer == GTK_RESPONSE_ACCEPT);
+	priv->reject_2G_files = (answer == GTK_RESPONSE_REJECT);
+
+	return (answer != GTK_RESPONSE_YES && answer != GTK_RESPONSE_ACCEPT);
 }
 
 static gboolean
@@ -969,8 +914,6 @@ brasero_data_disc_size_changed (gpointer user_data)
 	brasero_track_get_size (BRASERO_TRACK (priv->project),
 				&sectors,
 				NULL);
-	brasero_disc_size_changed (BRASERO_DISC (self), sectors);
-
 	priv->size_changed_id = 0;
 	return FALSE;
 }
@@ -1183,15 +1126,6 @@ brasero_data_disc_session_available_cb (BraseroTrackDataCfg *session,
 	}
 }
 
-static void
-brasero_data_disc_icon_changed_cb (BraseroTrackDataCfg *session,
-				   BraseroDataDisc *self)
-{
-	g_signal_emit (self,
-		       brasero_data_disc_signals [ICON_CHANGED],
-		       0);
-}
-
 static void
 brasero_data_disc_session_loaded_cb (BraseroTrackDataCfg *session,
 				     BraseroMedium *medium,
@@ -1211,12 +1145,6 @@ brasero_data_disc_session_loaded_cb (BraseroTrackDataCfg *session,
 	g_signal_handlers_block_by_func (action, brasero_data_disc_import_session_cb, self);
 	gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), loaded);
 	g_signal_handlers_unblock_by_func (action, brasero_data_disc_import_session_cb, self);
-
-	/* Update buttons states */
-	if (loaded)
-		brasero_disc_flags_changed (BRASERO_DISC (self), BRASERO_BURN_FLAG_MERGE);
-	else
-		brasero_disc_flags_changed (BRASERO_DISC (self), BRASERO_BURN_FLAG_NONE);
 }
 
 /**
@@ -1230,6 +1158,13 @@ brasero_data_disc_clear (BraseroDisc *disc)
 
 	priv = BRASERO_DATA_DISC_PRIVATE (disc);
 
+	priv->always_replace = FALSE;
+	priv->never_replace = FALSE;
+	priv->accept_deep_files = FALSE;
+	priv->reject_deep_files = FALSE;
+	priv->accept_2G_files = FALSE;
+	priv->reject_2G_files = FALSE;
+
 	if (priv->size_changed_id) {
 		g_source_remove (priv->size_changed_id);
 		priv->size_changed_id = 0;
@@ -1251,52 +1186,6 @@ brasero_data_disc_clear (BraseroDisc *disc)
 	brasero_notify_message_remove (BRASERO_NOTIFY (priv->message), BRASERO_NOTIFY_CONTEXT_MULTISESSION);
 
 	brasero_track_data_cfg_reset (priv->project);
-	brasero_disc_size_changed (disc, 0);
-
-	gdk_window_set_cursor (GTK_WIDGET (disc)->window, NULL);
-}
-
-static void
-brasero_data_disc_reset (BraseroDisc *disc)
-{
-	BraseroDataDiscPrivate *priv;
-
-	priv = BRASERO_DATA_DISC_PRIVATE (disc);
-
-	if (priv->size_changed_id) {
-		g_source_remove (priv->size_changed_id);
-		priv->size_changed_id = 0;
-	}
-
-	/* Unload session */
-	if (brasero_track_data_cfg_get_current_medium (BRASERO_TRACK_DATA_CFG (priv->project)))
-		brasero_track_data_cfg_unload_current_medium (BRASERO_TRACK_DATA_CFG (priv->project));
-
-	/* Hide all toggle actions for session importing */
-	if (gtk_action_group_get_visible (priv->import_group))
-		gtk_action_group_set_visible (priv->import_group, FALSE);
-
-	if (gtk_action_group_get_visible (priv->disc_group))
-		gtk_action_group_set_visible (priv->disc_group, FALSE);
-
-	if (priv->load_errors) {
-		g_slist_foreach (priv->load_errors, (GFunc) g_free , NULL);
-		g_slist_free (priv->load_errors);
-		priv->load_errors = NULL;
-	}
-
-	brasero_track_data_cfg_reset (priv->project);
-
-	brasero_notify_message_remove (BRASERO_NOTIFY (priv->message), BRASERO_NOTIFY_CONTEXT_SIZE);
-	brasero_notify_message_remove (BRASERO_NOTIFY (priv->message), BRASERO_NOTIFY_CONTEXT_LOADING);
-	brasero_notify_message_remove (BRASERO_NOTIFY (priv->message), BRASERO_NOTIFY_CONTEXT_MULTISESSION);
-
-	brasero_disc_size_changed (disc, 0);
-
-	if (GTK_WIDGET (disc)->window)
-		gdk_window_set_cursor (GTK_WIDGET (disc)->window, NULL);
-
-	gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook), 0);
 }
 
 static void
@@ -1363,7 +1252,6 @@ brasero_data_disc_add_uri (BraseroDisc *disc, const gchar *uri)
 		return BRASERO_DISC_LOADING;
 
 	parent = brasero_data_disc_get_parent (BRASERO_DATA_DISC (disc));
-	gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook), 1);
 	if (brasero_track_data_cfg_add (BRASERO_TRACK_DATA_CFG (priv->project), uri, parent)) {
 		gtk_tree_path_free (parent);
 		return BRASERO_DISC_OK;
@@ -1373,46 +1261,6 @@ brasero_data_disc_add_uri (BraseroDisc *disc, const gchar *uri)
 	return BRASERO_DISC_ERROR_UNKNOWN;
 }
 
-static BraseroDiscResult
-brasero_data_disc_get_track (BraseroDisc *disc,
-			     BraseroDiscTrack *track)
-{
-	gboolean res;
-	GSList *grafts = NULL;
-	GSList *excluded = NULL;
-	BraseroDataDiscPrivate *priv;
-
-	priv = BRASERO_DATA_DISC_PRIVATE (disc);
-
-	res = brasero_track_data_cfg_get_contents (BRASERO_TRACK_DATA (priv->project),
-						   &grafts,
-						   &excluded);
-	if (!res)
-		return BRASERO_DISC_ERROR_EMPTY_SELECTION;
-
-	track->contents.data.icon = g_strdup (brasero_track_data_cfg_get_icon_path (priv->project));
-	track->type = BRASERO_PROJECT_TYPE_DATA;
-	track->contents.data.grafts = grafts;
-	track->contents.data.excluded = excluded;
-
-	/* get restored */
-	track->contents.data.restored = brasero_track_data_cfg_get_restored_list (BRASERO_TRACK_DATA_CFG (priv->project));
-
-	return BRASERO_DISC_OK;
-}
-
-static BraseroDiscResult
-brasero_data_disc_set_session_contents (BraseroDisc *self,
-					BraseroBurnSession *session)
-{
-	BraseroDataDiscPrivate *priv;
-
-	priv = BRASERO_DATA_DISC_PRIVATE (self);
-
-	brasero_burn_session_add_track (session, BRASERO_TRACK (priv->project));
-	return BRASERO_DISC_OK;
-}
-
 static void
 brasero_data_disc_message_response_cb (BraseroDiscMessage *message,
 				       GtkResponseType response,
@@ -1432,42 +1280,125 @@ brasero_data_disc_message_response_cb (BraseroDiscMessage *message,
 }
 
 static BraseroDiscResult
-brasero_data_disc_load_track (BraseroDisc *disc,
-			      BraseroDiscTrack *track)
+brasero_data_disc_set_track (BraseroDataDisc *disc,
+			     BraseroTrackDataCfg *track)
 {
 	BraseroDataDiscPrivate *priv;
-	BraseroBurnResult res;
 	BraseroStatus *status;
 	GtkWidget *message;
-	GSList *iter;
 
 	priv = BRASERO_DATA_DISC_PRIVATE (disc);
 
-	/* First add the restored files */
-	for (iter = track->contents.data.restored; iter; iter = iter->next) {
-		gchar *uri;
+	priv->project = g_object_ref (track);
 
-		uri = iter->data;
-		brasero_track_data_cfg_dont_filter_uri (priv->project, uri);
+	/* filtered files */
+	priv->filter = brasero_file_filtered_new (priv->project);
+	brasero_file_filtered_set_right_button_group (BRASERO_FILE_FILTERED (priv->filter), priv->button_size);
+	g_signal_connect (priv->filter,
+			  "activate",
+			  G_CALLBACK (brasero_data_disc_filter_expanded_cb),
+			  disc);
+	gtk_widget_show (priv->filter);
+	gtk_box_pack_end (GTK_BOX (disc), priv->filter, FALSE, TRUE, 0);
+
+	/* Now let's take care of all the available sessions */
+	if (!priv->import_group) {
+		GSList *iter;
+		GSList *list;
+
+		priv->import_group = gtk_action_group_new ("session_import_group");
+		gtk_action_group_set_translation_domain (priv->import_group, GETTEXT_PACKAGE);
+		gtk_ui_manager_insert_action_group (priv->manager,
+						    priv->import_group,
+						    0);
+
+		list = brasero_track_data_cfg_get_available_media (priv->project);
+		for (iter = list; iter; iter = iter->next) {
+			BraseroMedium *medium;
+
+			medium = iter->data;
+			brasero_data_disc_import_button_new (BRASERO_DATA_DISC (disc), medium);
+		}
+		g_slist_foreach (list, (GFunc) g_object_unref, NULL);
+		g_slist_free (list);
 	}
+	else
+		gtk_action_group_set_visible (priv->import_group, TRUE);
 
-	res = brasero_track_data_set_source (BRASERO_TRACK_DATA (priv->project),
-					     track->contents.data.grafts,
-					     track->contents.data.excluded);
+	g_signal_connect (track,
+			  "2G-file",
+			  G_CALLBACK (brasero_data_disc_2G_file_cb),
+			  disc);
+	g_signal_connect (track,
+			  "deep-directory",
+			  G_CALLBACK (brasero_data_disc_deep_directory_cb),
+			  disc);
+	g_signal_connect (track,
+			  "name-collision",
+			  G_CALLBACK (brasero_data_disc_name_collision_cb),
+			  disc);
+	g_signal_connect (track,
+			  "joliet-rename",
+			  G_CALLBACK (brasero_data_disc_joliet_rename_cb),
+			  disc);
 
-	gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook), 1);
-	if (res == BRASERO_BURN_OK) {
+	g_signal_connect (track,
+			  "source-loading",
+			  G_CALLBACK (brasero_data_disc_project_loading_cb),
+			  disc);
+	g_signal_connect (track,
+			  "source-loaded",
+			  G_CALLBACK (brasero_data_disc_project_loaded_cb),
+			  disc);
+
+	/* Use the BraseroTrack "changed" signal for size changes */
+	g_signal_connect (track,
+			  "changed",
+			  G_CALLBACK (brasero_data_disc_size_changed_cb),
+			  disc);
+
+	g_signal_connect (track,
+			  "image-uri",
+			  G_CALLBACK (brasero_data_disc_image_uri_cb),
+			  disc);
+	g_signal_connect (track,
+			  "unreadable-uri",
+			  G_CALLBACK (brasero_data_disc_unreadable_uri_cb),
+			  disc);
+	g_signal_connect (track,
+			  "recursive-sym",
+			  G_CALLBACK (brasero_data_disc_recursive_uri_cb),
+			  disc);
+	g_signal_connect (track,
+			  "unknown-uri",
+			  G_CALLBACK (brasero_data_disc_unknown_uri_cb),
+			  disc);
+
+	g_signal_connect (track,
+			  "session-available",
+			  G_CALLBACK (brasero_data_disc_session_available_cb),
+			  disc);
+	g_signal_connect (track,
+			  "session-loaded",
+			  G_CALLBACK (brasero_data_disc_session_loaded_cb),
+			  disc);
+
+	gtk_tree_view_set_model (GTK_TREE_VIEW (priv->tree), GTK_TREE_MODEL (track));
+
+	status = brasero_status_new ();
+	brasero_track_get_status (BRASERO_TRACK (track), status);
+
+	if (brasero_status_get_result (status) == BRASERO_BURN_OK) {
+		brasero_status_free (status);
 		gtk_widget_set_sensitive (GTK_WIDGET (priv->tree), TRUE);
 		gtk_widget_set_sensitive (GTK_WIDGET (priv->filter), TRUE);
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook), 1);
 		return BRASERO_DISC_OK;
 	}
 
-	if (res != BRASERO_BURN_NOT_READY)
+	if (brasero_status_get_result (status) != BRASERO_BURN_NOT_READY) {
+		brasero_status_free (status);
 		return BRASERO_DISC_ERROR_UNKNOWN;
-
-	status = brasero_status_new ();
-	brasero_track_get_status (BRASERO_TRACK (priv->project), status);
+	}
 
 	message = brasero_notify_message_add (BRASERO_NOTIFY (priv->message),
 					      _("Please wait while the project is loading."),
@@ -1492,53 +1423,157 @@ brasero_data_disc_load_track (BraseroDisc *disc,
 	gtk_widget_set_sensitive (GTK_WIDGET (priv->tree), FALSE);
 	gtk_widget_set_sensitive (GTK_WIDGET (priv->filter), FALSE);
 
-	gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook), 1);
-
 	brasero_status_free (status);
-
-	/* The icon */
-	if (track->contents.data.icon)
-		brasero_track_data_cfg_set_icon (priv->project, track->contents.data.icon, NULL);
-
 	return BRASERO_DISC_OK;
 }
 
-static BraseroDiscResult
-brasero_data_disc_get_status (BraseroDisc *disc,
-			      gint *progress,
-			      gchar **current_task)
+static void
+brasero_data_disc_unset_track (BraseroDataDisc *disc)
 {
 	BraseroDataDiscPrivate *priv;
-	BraseroStatus *status;
 
 	priv = BRASERO_DATA_DISC_PRIVATE (disc);
 
-	status = brasero_status_new ();
-	brasero_track_get_status (BRASERO_TRACK (priv->project), status);
+	if (!priv->project)
+		return;
 
-	if (brasero_status_get_result (status) == BRASERO_BURN_NOT_READY) {
-		if (progress)
-			*progress = brasero_status_get_progress (status);
+	priv->always_replace = FALSE;
+	priv->never_replace = FALSE;
+	priv->accept_deep_files = FALSE;
+	priv->reject_deep_files = FALSE;
+	priv->accept_2G_files = FALSE;
+	priv->reject_2G_files = FALSE;
 
-		if (current_task)
-			*current_task = brasero_status_get_current_action (status);
-
-		brasero_status_free (status);
-
-		if (priv->loading)
-			return BRASERO_DISC_LOADING;
-
-		/* This one goes before the next since a node may be loading but not
-		 * yet in the project and therefore project will look empty */
-		return BRASERO_DISC_NOT_READY;
+	/* Remove filtered files widget */
+	if (priv->filter) {
+		gtk_widget_destroy (priv->filter);
+		priv->filter = NULL;
 	}
 
-	brasero_status_free (status);
+	/* Unload session */
+	if (brasero_track_data_cfg_get_current_medium (BRASERO_TRACK_DATA_CFG (priv->project)))
+		brasero_track_data_cfg_unload_current_medium (BRASERO_TRACK_DATA_CFG (priv->project));
 
-	if (!gtk_tree_model_iter_n_children (GTK_TREE_MODEL (priv->project), NULL))
-		return BRASERO_DISC_ERROR_EMPTY_SELECTION;
+	if (priv->size_changed_id) {
+		g_source_remove (priv->size_changed_id);
+		priv->size_changed_id = 0;
+	}
 
-	return BRASERO_DISC_OK;
+	/* Hide all toggle actions for session importing */
+	if (gtk_action_group_get_visible (priv->import_group))
+		gtk_action_group_set_visible (priv->import_group, FALSE);
+
+	if (gtk_action_group_get_visible (priv->disc_group))
+		gtk_action_group_set_visible (priv->disc_group, FALSE);
+
+	if (priv->load_errors) {
+		g_slist_foreach (priv->load_errors, (GFunc) g_free , NULL);
+		g_slist_free (priv->load_errors);
+		priv->load_errors = NULL;
+	}
+
+	g_signal_handlers_disconnect_by_func (priv->project,
+					      brasero_data_disc_2G_file_cb,
+					      disc);
+	g_signal_handlers_disconnect_by_func (priv->project,
+					      brasero_data_disc_deep_directory_cb,
+					      disc);
+	g_signal_handlers_disconnect_by_func (priv->project,
+					      brasero_data_disc_name_collision_cb,
+					      disc);
+	g_signal_handlers_disconnect_by_func (priv->project,
+					      brasero_data_disc_joliet_rename_cb,
+					      disc);
+	g_signal_handlers_disconnect_by_func (priv->project,
+					      brasero_data_disc_project_loading_cb,
+					      disc);
+	g_signal_handlers_disconnect_by_func (priv->project,
+					      brasero_data_disc_project_loaded_cb,
+					      disc);
+	g_signal_handlers_disconnect_by_func (priv->project,
+					      brasero_data_disc_size_changed_cb,
+					      disc);
+	g_signal_handlers_disconnect_by_func (priv->project,
+					      brasero_data_disc_image_uri_cb,
+					      disc);
+	g_signal_handlers_disconnect_by_func (priv->project,
+					      brasero_data_disc_unreadable_uri_cb,
+					      disc);
+	g_signal_handlers_disconnect_by_func (priv->project,
+					      brasero_data_disc_recursive_uri_cb,
+					      disc);
+	g_signal_handlers_disconnect_by_func (priv->project,
+					      brasero_data_disc_unknown_uri_cb,
+					      disc);
+	g_signal_handlers_disconnect_by_func (priv->project,
+					      brasero_data_disc_session_available_cb,
+					      disc);
+	g_signal_handlers_disconnect_by_func (priv->project,
+					      brasero_data_disc_session_loaded_cb,
+					      disc);
+
+	g_object_unref (priv->project);
+	priv->project = NULL;
+
+	gtk_tree_view_set_model (GTK_TREE_VIEW (priv->tree), NULL);
+}
+
+static void
+brasero_data_disc_track_removed (BraseroBurnSession *session,
+				 BraseroTrack *track,
+				 guint former_position,
+				 BraseroDataDisc *disc)
+{
+	g_signal_handlers_disconnect_by_func (session,
+					      brasero_data_disc_track_removed,
+					      disc);
+
+	brasero_data_disc_unset_track (disc);
+}
+
+static BraseroDiscResult
+brasero_data_disc_set_session_contents (BraseroDisc *self,
+					BraseroBurnSession *session)
+{
+	BraseroBurnResult result = BRASERO_BURN_OK;
+	BraseroDataDiscPrivate *priv;
+	GSList *tracks;
+
+	priv = BRASERO_DATA_DISC_PRIVATE (self);
+
+	brasero_data_disc_unset_track (BRASERO_DATA_DISC (self));
+
+	if (!session)
+		return BRASERO_DISC_OK;
+
+	/* get the track data */
+	tracks = brasero_burn_session_get_tracks (session);
+	if (!tracks) {
+		BraseroTrackDataCfg *data_track;
+
+		/* If it's empty add one */
+                data_track = brasero_track_data_cfg_new ();
+                brasero_burn_session_add_track (session,
+						BRASERO_TRACK (data_track),
+						NULL);
+		brasero_data_disc_set_track (BRASERO_DATA_DISC (self),
+					     BRASERO_TRACK_DATA_CFG (data_track));
+	}
+	else for (; tracks; tracks = tracks->next) {
+		BraseroTrack *track;
+
+		track = tracks->data;
+		if (BRASERO_IS_TRACK_DATA_CFG (track))
+			result = brasero_data_disc_set_track (BRASERO_DATA_DISC (self),
+							      BRASERO_TRACK_DATA_CFG (track));
+	}
+
+	g_signal_connect (session,
+			  "track-removed",
+			  G_CALLBACK (brasero_data_disc_track_removed),
+			  self);
+
+	return result;
 }
 
 static gboolean
@@ -1620,30 +1655,6 @@ brasero_data_disc_add_ui (BraseroDisc *disc,
 	else
 		gtk_action_group_set_visible (priv->disc_group, TRUE);
 
-	/* Now let's take care of all the available sessions */
-	if (!priv->import_group) {
-		GSList *iter;
-		GSList *list;
-
-		priv->import_group = gtk_action_group_new ("session_import_group");
-		gtk_action_group_set_translation_domain (priv->import_group, GETTEXT_PACKAGE);
-		gtk_ui_manager_insert_action_group (manager,
-						    priv->import_group,
-						    0);
-
-		list = brasero_track_data_cfg_get_available_media (priv->project);
-		for (iter = list; iter; iter = iter->next) {
-			BraseroMedium *medium;
-
-			medium = iter->data;
-			brasero_data_disc_import_button_new (BRASERO_DATA_DISC (disc), medium);
-		}
-		g_slist_foreach (list, (GFunc) g_object_unref, NULL);
-		g_slist_free (list);
-	}
-	else
-		gtk_action_group_set_visible (priv->import_group, TRUE);
-
 	return -1;
 }
 
@@ -2111,54 +2122,10 @@ brasero_data_disc_key_released_cb (GtkTreeView *tree,
 	return FALSE;
 }
 
-/**
- *
- */
-
-static void
-brasero_data_disc_contents_added_cb (GtkTreeModel *model,
-				     GtkTreePath *treepath,
-				     GtkTreeIter *iter,
-				     BraseroDataDisc *self)
-{
-	brasero_disc_contents_changed (BRASERO_DISC (self), TRUE);
-}
-
-static void
-brasero_data_disc_contents_removed_cb (GtkTreeModel *model,
-				       GtkTreePath *treepath,
-				       BraseroDataDisc *self)
-{
-	BraseroDataDiscPrivate *priv;
-
-	priv = BRASERO_DATA_DISC_PRIVATE (self);
-	brasero_disc_contents_changed (BRASERO_DISC (self), gtk_tree_model_iter_n_children (GTK_TREE_MODEL (priv->project), NULL));
-}
-
 /**
  * Misc functions
  */
 
-gboolean
-brasero_data_disc_set_icon_path (BraseroDataDisc *self,
-				 const gchar *path,
-				 GError **error)
-{
-	BraseroDataDiscPrivate *priv;
-
-	priv = BRASERO_DATA_DISC_PRIVATE (self);
-	return brasero_track_data_cfg_set_icon (priv->project, path, error);
-}
-
-gchar *
-brasero_data_disc_get_scaled_icon_path (BraseroDataDisc *disc)
-{
-	BraseroDataDiscPrivate *priv;
-
-	priv = BRASERO_DATA_DISC_PRIVATE (disc);
-	return brasero_track_data_cfg_get_scaled_icon_path (priv->project);
-}
-
 void
 brasero_data_disc_set_right_button_group (BraseroDataDisc *self,
 					  GtkSizeGroup *size_group)
@@ -2166,7 +2133,7 @@ brasero_data_disc_set_right_button_group (BraseroDataDisc *self,
 	BraseroDataDiscPrivate *priv;
 
 	priv = BRASERO_DATA_DISC_PRIVATE (self);
-	brasero_file_filtered_set_right_button_group (BRASERO_FILE_FILTERED (priv->filter), size_group);
+	priv->button_size = g_object_ref (size_group);
 }
 
 /**
@@ -2186,101 +2153,12 @@ brasero_data_disc_init (BraseroDataDisc *object)
 
 	gtk_box_set_spacing (GTK_BOX (object), 8);
 
-	/* the information displayed about how to use this tree */
-	priv->notebook = brasero_disc_get_use_info_notebook ();
-	gtk_widget_show (priv->notebook);
-	gtk_box_pack_start (GTK_BOX (object), priv->notebook, TRUE, TRUE, 0);
-
 	mainbox = gtk_vbox_new (FALSE, 0);
 	gtk_widget_show (mainbox);
-	gtk_notebook_append_page (GTK_NOTEBOOK (priv->notebook), mainbox, NULL);
-	gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook), 0);
-
-	priv->project = brasero_track_data_cfg_new ();
-
-	g_signal_connect (priv->project,
-			  "2G-file",
-			  G_CALLBACK (brasero_data_disc_2G_file_cb),
-			  object);
-	g_signal_connect (priv->project,
-			  "deep-directory",
-			  G_CALLBACK (brasero_data_disc_deep_directory_cb),
-			  object);
-
-	g_signal_connect (priv->project,
-			  "source-loading",
-			  G_CALLBACK (brasero_data_disc_project_loading_cb),
-			  object);
-	g_signal_connect (priv->project,
-			  "source-loaded",
-			  G_CALLBACK (brasero_data_disc_project_loaded_cb),
-			  object);
-
-	g_signal_connect (priv->project,
-			  "session-oversized",
-			  G_CALLBACK (brasero_data_disc_project_oversized_cb),
-			  object);
-
-	/* Use the BraseroTrack "changed" signal */
-	g_signal_connect (priv->project,
-			  "changed",
-			  G_CALLBACK (brasero_data_disc_size_changed_cb),
-			  object);
-	g_signal_connect (priv->project,
-			  "name-collision",
-			  G_CALLBACK (brasero_data_disc_name_collision_cb),
-			  object);
-	g_signal_connect (priv->project,
-			  "joliet-rename",
-			  G_CALLBACK (brasero_data_disc_joliet_rename_cb),
-			  object);
-	g_signal_connect (priv->project,
-			  "row-inserted",
-			  G_CALLBACK (brasero_data_disc_contents_added_cb),
-			  object);
-	g_signal_connect (priv->project,
-			  "row-deleted",
-			  G_CALLBACK (brasero_data_disc_contents_removed_cb),
-			  object);
-
-	g_signal_connect (priv->project,
-			  "vfs-activity",
-			  G_CALLBACK (brasero_data_disc_activity_changed_cb),
-			  object);
-	g_signal_connect (priv->project,
-			  "image-uri",
-			  G_CALLBACK (brasero_data_disc_image_uri_cb),
-			  object);
-	g_signal_connect (priv->project,
-			  "unreadable-uri",
-			  G_CALLBACK (brasero_data_disc_unreadable_uri_cb),
-			  object);
-	g_signal_connect (priv->project,
-			  "recursive-sym",
-			  G_CALLBACK (brasero_data_disc_recursive_uri_cb),
-			  object);
-	g_signal_connect (priv->project,
-			  "unknown-uri",
-			  G_CALLBACK (brasero_data_disc_unknown_uri_cb),
-			  object);
-
-	g_signal_connect (priv->project,
-			  "session-available",
-			  G_CALLBACK (brasero_data_disc_session_available_cb),
-			  object);
-
-	g_signal_connect (priv->project,
-			  "session-loaded",
-			  G_CALLBACK (brasero_data_disc_session_loaded_cb),
-			  object);
-
-	g_signal_connect (priv->project,
-			  "icon-changed",
-			  G_CALLBACK (brasero_data_disc_icon_changed_cb),
-			  object);
+	gtk_box_pack_start (GTK_BOX (object), mainbox, TRUE, TRUE, 0);
 
 	/* Tree */
-	priv->tree = gtk_tree_view_new_with_model (GTK_TREE_MODEL (priv->project));
+	priv->tree = gtk_tree_view_new ();
 	gtk_tree_view_set_rubber_banding (GTK_TREE_VIEW (priv->tree), TRUE);
 
 	/* This must be before connecting to button press event */
@@ -2414,15 +2292,6 @@ brasero_data_disc_init (BraseroDataDisc *object)
 						ntables_source,
 						nb_targets_source,
 						GDK_ACTION_MOVE);
-
-	/* filtered files */
-	priv->filter = brasero_file_filtered_new (priv->project);
-	g_signal_connect (priv->filter,
-			  "activate",
-			  G_CALLBACK (brasero_data_disc_filter_expanded_cb),
-			  object);
-	gtk_widget_show (priv->filter);
-	gtk_box_pack_end (GTK_BOX (object), priv->filter, FALSE, TRUE, 0);
 }
 
 static void
@@ -2432,6 +2301,11 @@ brasero_data_disc_finalize (GObject *object)
 
 	priv = BRASERO_DATA_DISC_PRIVATE (object);
 
+	if (priv->button_size) {
+		g_object_unref (priv->button_size);
+		priv->button_size = NULL;
+	}
+
 	if (priv->size_changed_id) {
 		g_source_remove (priv->size_changed_id);
 		priv->size_changed_id = 0;
@@ -2457,11 +2331,7 @@ brasero_data_disc_iface_disc_init (BraseroDiscIface *iface)
 	iface->add_uri = brasero_data_disc_add_uri;
 	iface->delete_selected = brasero_data_disc_delete_selected;
 	iface->clear = brasero_data_disc_clear;
-	iface->reset = brasero_data_disc_reset;
-	iface->get_track = brasero_data_disc_get_track;
 	iface->set_session_contents = brasero_data_disc_set_session_contents;
-	iface->load_track = brasero_data_disc_load_track;
-	iface->get_status = brasero_data_disc_get_status;
 	iface->get_selected_uri = brasero_data_disc_get_selected_uri;
 	iface->add_ui = brasero_data_disc_add_ui;
 }
@@ -2516,17 +2386,6 @@ brasero_data_disc_class_init (BraseroDataDiscClass *klass)
 	object_class->set_property = brasero_data_disc_set_property;
 	object_class->get_property = brasero_data_disc_get_property;
 
-	brasero_data_disc_signals [ICON_CHANGED] = 
-	    g_signal_new ("icon_changed",
-			  G_TYPE_FROM_CLASS (klass),
-			  G_SIGNAL_RUN_LAST|G_SIGNAL_NO_RECURSE,
-			  0,
-			  NULL, NULL,
-			  g_cclosure_marshal_VOID__VOID,
-			  G_TYPE_NONE,
-			  0,
-			  G_TYPE_NONE);
-
 	g_object_class_install_property (object_class,
 					 PROP_REJECT_FILE,
 					 g_param_spec_boolean
