@@ -1,5 +1,5 @@
 /***************************************************************************
- *            disc.h
+ *            brasero-disc.h
  *
  *  dim nov 27 14:58:13 2005
  *  Copyright  2005  Rouquier Philippe
@@ -30,11 +30,11 @@
 #include <glib.h>
 #include <glib-object.h>
 
-#include <gtk/gtktoolbar.h>
-#include <gtk/gtkuimanager.h>
+#include <gtk/gtk.h>
 
+#include "brasero-project-parse.h"
 #include "burn-basics.h"
-#include "burn-session.h"
+#include "brasero-session.h"
 
 G_BEGIN_DECLS
 
@@ -64,37 +64,6 @@ typedef enum {
 	BRASERO_DISC_ERROR_UNKNOWN
 } BraseroDiscResult;
 
-typedef enum {
-	BRASERO_DISC_TRACK_NONE = 0,
-	BRASERO_DISC_TRACK_AUDIO,
-	BRASERO_DISC_TRACK_VIDEO,
-	BRASERO_DISC_TRACK_DATA,
-} BraseroDiscTrackType;
-
-struct _BraseroDiscSong {
-	gchar *uri;
-	gint64 gap;
-	gint64 start;
-	gint64 end;
-
-	BraseroSongInfo *info;
-};
-typedef struct _BraseroDiscSong BraseroDiscSong;
-
-typedef struct {
-	BraseroDiscTrackType type;
-
-	union  {
-		struct {
-			GSList *grafts;
-			GSList *excluded;
-			GSList *restored;
-		} data;
-
-		GSList *tracks; /* BraseroDiscSong */
-	} contents;
-} BraseroDiscTrack;
-
 typedef struct _BraseroDisc        BraseroDisc;
 typedef struct _BraseroDiscIface   BraseroDiscIface;
 
@@ -103,28 +72,11 @@ struct _BraseroDiscIface {
 
 	/* signals */
 	void	(*selection_changed)			(BraseroDisc *disc);
-	void	(*contents_changed)			(BraseroDisc *disc,
-							 gint nb_files);
-	void	(*size_changed)				(BraseroDisc *disc,
-							 gint64 size);
-	void	(*flags_changed)			(BraseroDisc *disc,
-							 BraseroBurnFlag flags);
 
 	/* virtual functions */
-	BraseroDiscResult	(*get_status)		(BraseroDisc *disc);
-
-	BraseroDiscResult	(*load_track)		(BraseroDisc *disc,
-							 BraseroDiscTrack *track);
-	BraseroDiscResult	(*get_track)		(BraseroDisc *disc,
-							 BraseroDiscTrack *track);
-
-	BraseroDiscResult	(*set_session_param)	(BraseroDisc *disc,
-							 BraseroBurnSession *session);
 	BraseroDiscResult	(*set_session_contents)	(BraseroDisc *disc,
 							 BraseroBurnSession *session);
 
-	BraseroDiscResult	(*can_add_uri)		(BraseroDisc *disc,
-							 const gchar *uri);
 	BraseroDiscResult	(*add_uri)		(BraseroDisc *disc,
 							 const gchar *uri);
 
@@ -136,7 +88,6 @@ struct _BraseroDiscIface {
 
 	void			(*delete_selected)	(BraseroDisc *disc);
 	void			(*clear)		(BraseroDisc *disc);
-	void			(*reset)		(BraseroDisc *disc);
 
 	guint			(*add_ui)		(BraseroDisc *disc,
 							 GtkUIManager *manager,
@@ -153,9 +104,6 @@ brasero_disc_add_ui (BraseroDisc *disc,
 BraseroDiscResult
 brasero_disc_add_uri (BraseroDisc *disc, const gchar *escaped_uri);
 
-BraseroDiscResult
-brasero_disc_can_add_uri (BraseroDisc *disc, const gchar *escaped_uri);
-
 gboolean
 brasero_disc_get_selected_uri (BraseroDisc *disc, gchar **uri);
 
@@ -166,46 +114,20 @@ brasero_disc_get_boundaries (BraseroDisc *disc,
 
 void
 brasero_disc_delete_selected (BraseroDisc *disc);
-void
+
+gboolean
 brasero_disc_clear (BraseroDisc *disc);
-void
-brasero_disc_reset (BraseroDisc *disc);
 
 BraseroDiscResult
-brasero_disc_get_status (BraseroDisc *disc);
+brasero_disc_get_status (BraseroDisc *disc,
+			 gint *remaining,
+			 gchar **current_task);
 
-BraseroDiscResult
-brasero_disc_get_track (BraseroDisc *disc,
-			BraseroDiscTrack *track);
-BraseroDiscResult
-brasero_disc_load_track (BraseroDisc *disc,
-			 BraseroDiscTrack *track);
-
-BraseroDiscResult
-brasero_disc_set_session_param (BraseroDisc *disc,
-				BraseroBurnSession *session);
 BraseroDiscResult
 brasero_disc_set_session_contents (BraseroDisc *disc,
 				   BraseroBurnSession *session);
 
 void
-brasero_disc_size_changed (BraseroDisc *disc,
-			   gint64 size);
-void
-brasero_disc_flags_changed (BraseroDisc *disc,
-			    BraseroBurnFlag flags);
-void
-brasero_disc_contents_changed (BraseroDisc *disc,
-			       gint nb_files);
-void
 brasero_disc_selection_changed (BraseroDisc *disc);
 
-void
-brasero_track_clear (BraseroDiscTrack *track);
-void
-brasero_track_free (BraseroDiscTrack *track);
-
-GtkWidget *
-brasero_disc_get_use_info_notebook (void);
-
 #endif /* DISC_H */
