@@ -43,13 +43,9 @@
 #include "brasero-project-manager.h"
 #include "brasero-file-chooser.h"
 #include "brasero-uri-container.h"
-#include "brasero-image-option-dialog.h"
-#include "brasero-burn-dialog.h"
 #include "brasero-project-type-chooser.h"
-#include "brasero-disc-copy-dialog.h"
 #include "brasero-io.h"
-#include "burn-caps.h"
-#include "burn-medium-monitor.h"
+#include "brasero-medium-monitor.h"
 
 #ifdef BUILD_SEARCH
 #include "brasero-search-beagle.h"
@@ -115,7 +111,7 @@ static GtkActionEntry entries [] = {
 	{"NewVideo", "media-optical-video-new", N_("New _Video Project"), NULL,
 	 N_("Create a video DVD or a SVCD that are readable on TV readers"), G_CALLBACK (brasero_project_manager_new_video_prj_cb)},
 	{"NewCopy", "media-optical-copy", N_("Copy _Disc..."), NULL,
-	 N_("Create a 1:1 copy of an audio CD or a data CD/DVD on your hardisk or on another CD/DVD"), G_CALLBACK (brasero_project_manager_new_copy_prj_cb)},
+	 N_("Create a 1:1 copy of an audio CD or a data CD/DVD on your hard disk or on another CD/DVD"), G_CALLBACK (brasero_project_manager_new_copy_prj_cb)},
 	{"NewIso", "iso-image-burn", N_("_Burn Image..."), NULL,
 	 N_("Burn an existing CD/DVD image to disc"), G_CALLBACK (brasero_project_manager_new_iso_prj_cb)},
 
@@ -160,7 +156,6 @@ static const char *description = {
 };
 
 struct BraseroProjectManagerPrivate {
-	BraseroIO *io;
 	BraseroProjectType type;
 	BraseroIOJobBase *size_preview;
 
@@ -173,8 +168,6 @@ struct BraseroProjectManagerPrivate {
 	guint status_ctx;
 
 	GtkActionGroup *action_group;
-
-	guint oneshot:1;
 };
 
 #define BRASERO_PROJECT_MANAGER_CONNECT_CHANGED(manager, container)		\
@@ -216,15 +209,19 @@ static void
 brasero_project_manager_new_cover_cb (GtkAction *action,
 				      BraseroProjectManager *manager)
 {
+	BraseroJacketEdit *edit;
 	GtkWidget *toplevel;
-	GtkWidget *edit;
+	GtkWidget *dialog;
+
+	if (manager->priv->type == BRASERO_PROJECT_TYPE_AUDIO) {
+		brasero_project_create_audio_cover (BRASERO_PROJECT (manager->priv->project), edit);
+		return;
+	}
 
 	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (manager));
-	edit = brasero_jacket_edit_dialog_new (toplevel, NULL);
-
-	if (manager->priv->type == BRASERO_PROJECT_TYPE_AUDIO)
-		brasero_project_set_cover_specifics (BRASERO_PROJECT (manager->priv->project),
-						     BRASERO_JACKET_EDIT (edit));
+	dialog = brasero_jacket_edit_dialog_new (toplevel, &edit);
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
 }
 
 static void
@@ -234,12 +231,10 @@ brasero_project_manager_set_statusbar (BraseroProjectManager *manager,
 				       gint files_num)
 {
 	gchar *status_string = NULL;
-	GtkWidget *toplevel;
 	GtkWidget *status;
 	gint valid_num;
 
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (manager));
-	status = brasero_app_get_statusbar1 (BRASERO_APP (toplevel));
+	status = brasero_app_get_statusbar1 (brasero_app_get_default ());
 
 	if (!manager->priv->status_ctx)
 		manager->priv->status_ctx = gtk_statusbar_get_context_id (GTK_STATUSBAR (status),
@@ -252,7 +247,7 @@ brasero_project_manager_set_statusbar (BraseroProjectManager *manager,
 		gchar *size_string;
 
 		if (manager->priv->type == BRASERO_PROJECT_TYPE_AUDIO)
-			size_string = brasero_utils_get_time_string (files_size, TRUE, FALSE);
+			size_string = brasero_units_get_time_string (files_size, TRUE, FALSE);
 		else if (manager->priv->type == BRASERO_PROJECT_TYPE_DATA)
 			size_string = g_format_size_for_display (files_size);
 		else
@@ -267,7 +262,7 @@ brasero_project_manager_set_statusbar (BraseroProjectManager *manager,
 		gchar *size_string = NULL;
 
 		if (manager->priv->type == BRASERO_PROJECT_TYPE_AUDIO) {
-			size_string = brasero_utils_get_time_string (files_size, TRUE, FALSE);
+			size_string = brasero_units_get_time_string (files_size, TRUE, FALSE);
 			status_string = g_strdup_printf (ngettext ("%d file is supported (%s)", "%d files are supported (%s)", valid_num),
 							 valid_num,
 							 size_string);
@@ -323,7 +318,7 @@ brasero_project_manager_size_preview (GObject *object,
 					       invalid_num,
 					       files_num);
 }
-
+/*
 static void
 brasero_project_manager_size_preview_progress (GObject *object,
 					       BraseroIOJobProgress *progress,
@@ -340,7 +335,7 @@ brasero_project_manager_size_preview_progress (GObject *object,
 					       0,
 					       files_num);
 }
-
+*/
 static gboolean
 brasero_project_manager_selected_uris_preview (gpointer data)
 {
@@ -349,14 +344,11 @@ brasero_project_manager_selected_uris_preview (gpointer data)
 	GSList *list = NULL;
 	gchar **iter;
 
-	if (!manager->priv->io)
-		manager->priv->io = brasero_io_get_default ();
-
 	if (!manager->priv->size_preview)
 		manager->priv->size_preview = brasero_io_register (G_OBJECT (manager),
 								   brasero_project_manager_size_preview,
 								   NULL,
-								   brasero_project_manager_size_preview_progress);
+								   NULL);
     
 	for (iter = manager->priv->selected; iter && *iter; iter ++)
 		list = g_slist_prepend (list, *iter);
@@ -368,8 +360,7 @@ brasero_project_manager_selected_uris_preview (gpointer data)
 	else if (manager->priv->type == BRASERO_PROJECT_TYPE_DATA)
 		flags |= BRASERO_IO_INFO_RECURSIVE;
 
-	brasero_io_get_file_count (manager->priv->io,
-				   list,
+	brasero_io_get_file_count (list,
 				   manager->priv->size_preview,
 				   flags,
 				   NULL);
@@ -428,9 +419,8 @@ brasero_project_manager_selected_uris_changed (BraseroURIContainer *container,
 
 	/* if we are in the middle of an unfinished size seek then
 	 * cancel it and re-initialize */
-	if (manager->priv->io)
-		brasero_io_cancel_by_base (manager->priv->io,
-					   manager->priv->size_preview);
+	if (manager->priv->size_preview)
+		brasero_io_cancel_by_base (manager->priv->size_preview);
 
 	if (manager->priv->selected) {
 		g_strfreev (manager->priv->selected);
@@ -444,11 +434,9 @@ brasero_project_manager_selected_uris_changed (BraseroURIContainer *container,
 
 	manager->priv->selected = uris;
 	if (!manager->priv->selected) {
-		GtkWidget *toplevel;
  		GtkWidget *status;
  
- 		toplevel = gtk_widget_get_toplevel (GTK_WIDGET (manager));
- 		status = brasero_app_get_statusbar1 (BRASERO_APP (toplevel));
+ 		status = brasero_app_get_statusbar1 (brasero_app_get_default ());
  
  		if (!manager->priv->status_ctx)
  			manager->priv->status_ctx = gtk_statusbar_get_context_id (GTK_STATUSBAR (status),
@@ -472,16 +460,13 @@ brasero_project_manager_sidepane_changed (BraseroLayout *layout,
 					  BraseroProjectManager *manager)
 {
 	if (!visible) {
-		GtkWidget *toplevel;
  		GtkWidget *status;
  
 		/* If sidepane is disabled, remove any text about selection */
-		if (manager->priv->io)
-			brasero_io_cancel_by_base (manager->priv->io,
-						   manager->priv->size_preview);
+		if (manager->priv->size_preview)
+			brasero_io_cancel_by_base (manager->priv->size_preview);
 
- 		toplevel = gtk_widget_get_toplevel (GTK_WIDGET (manager));
- 		status = brasero_app_get_statusbar1 (BRASERO_APP (toplevel));
+ 		status = brasero_app_get_statusbar1 (brasero_app_get_default ());
 
  		gtk_statusbar_pop (GTK_STATUSBAR (status), manager->priv->status_ctx);
 
@@ -513,159 +498,6 @@ brasero_project_manager_register_ui (BraseroProjectManager *manager,
    	brasero_layout_register_ui (BRASERO_LAYOUT (manager->priv->layout), ui_manager);
 }
 
-static void
-brasero_project_manager_burn (BraseroProjectManager *manager,
-			      BraseroBurnSession *session)
-{
-	GtkWidget *toplevel;
-	GtkWidget *dialog;
-
-	/* now setup the burn dialog */
-	dialog = brasero_burn_dialog_new ();
-
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (manager));
-	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (toplevel));
-	gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
-
-	gtk_widget_hide (toplevel);
-	gtk_widget_show (dialog);
-
-	brasero_burn_dialog_run (BRASERO_BURN_DIALOG (dialog),
-				 session);
-
-	gtk_widget_destroy (dialog);
-
-	brasero_project_manager_switch (manager,
-					BRASERO_PROJECT_TYPE_INVALID,
-					NULL,
-					NULL,
-					TRUE);
-	gtk_widget_show (toplevel);
-}
-
-static void
-brasero_project_manager_burn_iso_dialog (BraseroProjectManager *manager,
-					 const gchar *uri)
-{
-	BraseroBurnSession *session;
-	GtkResponseType result;
-	GtkWidget *toplevel;
-	GtkWidget *dialog;
-
-	/* setup, show, and run options dialog */
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (manager));
-
-	dialog = brasero_image_option_dialog_new ();
-	brasero_image_option_dialog_set_image_uri (BRASERO_IMAGE_OPTION_DIALOG (dialog), uri);
-
-	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (toplevel));
-	gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
-	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER_ON_PARENT);
-	gtk_widget_show (dialog);
-
-	result = gtk_dialog_run (GTK_DIALOG (dialog));
-	if (result != GTK_RESPONSE_OK) {
-		gtk_widget_destroy (dialog);
-
-		/* Here we may have to close brasero altogether */
-		if (manager->priv->oneshot) {
-			GtkWidget *toplevel;
-
-			toplevel = gtk_widget_get_toplevel (GTK_WIDGET (manager));
-			gtk_widget_destroy (toplevel);
-		}
-
-		return;
-	}
-
-	session = brasero_burn_options_get_session (BRASERO_BURN_OPTIONS (dialog));
-	gtk_widget_destroy (dialog);
-
-	brasero_project_manager_burn (manager, session);
-	g_object_unref (session);
-
-	/* Here we may have to close brasero altogether */
-	if (manager->priv->oneshot) {
-		GtkWidget *toplevel;
-
-		toplevel = gtk_widget_get_toplevel (GTK_WIDGET (manager));
-		gtk_widget_destroy (toplevel);
-	}
-}
-
-static void
-brasero_project_manager_copy_disc (BraseroProjectManager *manager,
-				   const gchar *device,
-				   const gchar *cover)
-{
-	BraseroBurnSession *session;
-	GtkResponseType result;
-	GtkWidget *toplevel;
-	GtkWidget *dialog;
-
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (manager));
-
-	dialog = brasero_disc_copy_dialog_new ();
-	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (toplevel));
-	gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
-	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER_ON_PARENT);
-	gtk_widget_show (dialog);
-
-	/* if a device is specified then get the corresponding medium */
-	if (device) {
-		BraseroDrive *drive;
-		BraseroMediumMonitor *monitor;
-
-		monitor = brasero_medium_monitor_get_default ();
-		drive = brasero_medium_monitor_get_drive (monitor, device);
-		g_object_unref (monitor);
-
-		brasero_disc_copy_dialog_set_drive (BRASERO_DISC_COPY_DIALOG (dialog), drive);
-		g_object_unref (drive);
-	}
-
-	result = gtk_dialog_run (GTK_DIALOG (dialog));
-	if (result != GTK_RESPONSE_OK) {
-		gtk_widget_destroy (dialog);
-
-		/* Here we may have to close brasero altogether */
-		if (manager->priv->oneshot) {
-			GtkWidget *toplevel;
-
-			toplevel = gtk_widget_get_toplevel (GTK_WIDGET (manager));
-			gtk_widget_destroy (toplevel);
-		}
-
-		return;
-	}
-
-	session = brasero_burn_options_get_session (BRASERO_BURN_OPTIONS (dialog));
-	gtk_widget_destroy (dialog);
-
-	/* Set a cover if any. */
-	if (cover) {
-		GValue *value;
-
-		value = g_new0 (GValue, 1);
-		g_value_init (value, G_TYPE_STRING);
-		g_value_set_string (value, cover);
-		brasero_burn_session_tag_add (session,
-					      BRASERO_COVER_URI,
-					      value);
-	}
-
-	brasero_project_manager_burn (manager, session);
-	g_object_unref (session);
-
-	/* Here we may have to close brasero altogether */
-	if (manager->priv->oneshot) {
-		GtkWidget *toplevel;
-
-		toplevel = gtk_widget_get_toplevel (GTK_WIDGET (manager));
-		gtk_widget_destroy (toplevel);
-	}
-}
-
 static void
 brasero_project_manager_switch (BraseroProjectManager *manager,
 				BraseroProjectType type,
@@ -683,25 +515,18 @@ brasero_project_manager_switch (BraseroProjectManager *manager,
 	||  manager->priv->type == BRASERO_PROJECT_TYPE_VIDEO) {
 		if (!brasero_project_confirm_switch (BRASERO_PROJECT (manager->priv->project)))
 			return;
-
-		if (manager->priv->oneshot) {
-			/* Here we may have to close brasero altogether */
-			gtk_widget_destroy (toplevel);
-			return;
-		}
 	}
 
 	if (manager->priv->status_ctx) {
 		GtkWidget *status;
 
-		status = brasero_app_get_statusbar1 (BRASERO_APP (toplevel));
+		status = brasero_app_get_statusbar1 (brasero_app_get_default ());
 		gtk_statusbar_pop (GTK_STATUSBAR (status), manager->priv->status_ctx);
 	}
 
 	action = gtk_action_group_get_action (manager->priv->action_group, "NewChoose");
 
 	manager->priv->type = type;
-
 	if (type == BRASERO_PROJECT_TYPE_INVALID) {
 		brasero_layout_load (BRASERO_LAYOUT (manager->priv->layout), BRASERO_LAYOUT_NONE);
 		brasero_project_set_none (BRASERO_PROJECT (manager->priv->project));
@@ -763,7 +588,13 @@ brasero_project_manager_switch (BraseroProjectManager *manager,
 
 		if (toplevel)
 			gtk_window_set_title (GTK_WINDOW (toplevel), _("Brasero - New Image File"));
-		brasero_project_manager_burn_iso_dialog (manager, uri);
+
+		brasero_project_manager_switch (manager,
+						BRASERO_PROJECT_TYPE_INVALID,
+						NULL,
+						NULL,
+						TRUE);
+		brasero_app_burn_image (brasero_app_get_default (), uri);
 	}
 	else if (type == BRASERO_PROJECT_TYPE_COPY) {
 		brasero_layout_load (BRASERO_LAYOUT (manager->priv->layout), BRASERO_LAYOUT_NONE);
@@ -775,7 +606,12 @@ brasero_project_manager_switch (BraseroProjectManager *manager,
 		if (toplevel)
 			gtk_window_set_title (GTK_WINDOW (toplevel), _("Brasero - Disc Copy"));
 
-		brasero_project_manager_copy_disc (manager, uri, NULL);
+		brasero_project_manager_switch (manager,
+						BRASERO_PROJECT_TYPE_INVALID,
+						NULL,
+						NULL,
+						TRUE);
+		brasero_app_copy_disc (brasero_app_get_default (), uri, NULL);
 	}
 }
 
@@ -784,66 +620,49 @@ brasero_project_manager_type_changed_cb (BraseroProjectTypeChooser *chooser,
 					 BraseroProjectType type,
 					 BraseroProjectManager *manager)
 {
-	manager->priv->oneshot = FALSE;
 	brasero_project_manager_switch (manager, type, NULL, NULL, TRUE);
 }
 
 static void
 brasero_project_manager_new_empty_prj_cb (GtkAction *action, BraseroProjectManager *manager)
 {
-	manager->priv->oneshot = FALSE;
 	brasero_project_manager_switch (manager, BRASERO_PROJECT_TYPE_INVALID, NULL, NULL, TRUE);
 }
 
 static void
 brasero_project_manager_new_audio_prj_cb (GtkAction *action, BraseroProjectManager *manager)
 {
-	manager->priv->oneshot = FALSE;
 	brasero_project_manager_switch (manager, BRASERO_PROJECT_TYPE_AUDIO, NULL, NULL, TRUE);
 }
 
 static void
 brasero_project_manager_new_data_prj_cb (GtkAction *action, BraseroProjectManager *manager)
 {
-	manager->priv->oneshot = FALSE;
 	brasero_project_manager_switch (manager, BRASERO_PROJECT_TYPE_DATA, NULL, NULL, TRUE);
 }
 
 static void
 brasero_project_manager_new_video_prj_cb (GtkAction *action, BraseroProjectManager *manager)
 {
-	manager->priv->oneshot = FALSE;
 	brasero_project_manager_switch (manager, BRASERO_PROJECT_TYPE_VIDEO, NULL, NULL, TRUE);
 }
 
 static void
 brasero_project_manager_new_copy_prj_cb (GtkAction *action, BraseroProjectManager *manager)
 {
-	manager->priv->oneshot = FALSE;
 	brasero_project_manager_switch (manager, BRASERO_PROJECT_TYPE_COPY, NULL, NULL, TRUE);
 }
 
 static void
 brasero_project_manager_new_iso_prj_cb (GtkAction *action, BraseroProjectManager *manager)
 {
-	manager->priv->oneshot = FALSE;
 	brasero_project_manager_switch (manager, BRASERO_PROJECT_TYPE_ISO, NULL, NULL, TRUE);
 }
 
-void
-brasero_project_manager_audio (BraseroProjectManager *manager,
-			       GSList *uris)
-{
-	brasero_project_manager_switch (manager,
-					BRASERO_PROJECT_TYPE_AUDIO,
-					uris,
-					NULL,
-					TRUE);
-}
-
 void
 brasero_project_manager_data (BraseroProjectManager *manager,
-			      GSList *uris)
+			      GSList *uris,
+			      gboolean burn)
 {
 	gchar *burn_URI = NULL;
 
@@ -853,9 +672,8 @@ brasero_project_manager_data (BraseroProjectManager *manager,
 		uris = g_slist_prepend (NULL, burn_URI);
 	}
 
-	if (manager->priv->oneshot) {
-		brasero_project_set_data (BRASERO_PROJECT (manager->priv->project),
-					  uris);
+	if (burn) {
+		brasero_project_set_data (BRASERO_PROJECT (manager->priv->project), uris);
 		brasero_project_burn (BRASERO_PROJECT (manager->priv->project));
 	}
 	else
@@ -864,7 +682,7 @@ brasero_project_manager_data (BraseroProjectManager *manager,
 						uris,
 						NULL,
 						TRUE);
-	
+
 	if (burn_URI) {
 		g_slist_free (uris);
 		g_free (burn_URI);
@@ -872,14 +690,37 @@ brasero_project_manager_data (BraseroProjectManager *manager,
 }
 
 void
-brasero_project_manager_video (BraseroProjectManager *manager,
-			       GSList *uris)
+brasero_project_manager_audio (BraseroProjectManager *manager,
+			       GSList *uris,
+			       gboolean burn)
 {
-	brasero_project_manager_switch (manager,
-					BRASERO_PROJECT_TYPE_VIDEO,
-					uris,
-					NULL,
-					TRUE);
+	if (burn) {
+		brasero_project_set_audio (BRASERO_PROJECT (manager->priv->project), uris);
+		brasero_project_burn (BRASERO_PROJECT (manager->priv->project));
+	}
+	else
+		brasero_project_manager_switch (manager,
+						BRASERO_PROJECT_TYPE_AUDIO,
+						uris,
+						NULL,
+						TRUE);
+}
+
+void
+brasero_project_manager_video (BraseroProjectManager *manager,
+			       GSList *uris,
+			       gboolean burn)
+{
+	if (burn) {
+		brasero_project_set_video (BRASERO_PROJECT (manager->priv->project), uris);
+		brasero_project_burn (BRASERO_PROJECT (manager->priv->project));
+	}
+	else
+		brasero_project_manager_switch (manager,
+						BRASERO_PROJECT_TYPE_VIDEO,
+						uris,
+						NULL,
+						TRUE);
 }
 
 void
@@ -887,14 +728,11 @@ brasero_project_manager_copy (BraseroProjectManager *manager,
 			      const gchar *device,
 			      const gchar *cover)
 {
-	if (manager->priv->oneshot)
-		brasero_project_manager_copy_disc (manager, device, cover);
-	else
-		brasero_project_manager_switch (manager,
-						BRASERO_PROJECT_TYPE_COPY,
-						NULL,
-						device,
-						TRUE);
+	brasero_project_manager_switch (manager,
+					BRASERO_PROJECT_TYPE_COPY,
+					NULL,
+					device,
+					TRUE);
 }
 
 void
@@ -910,75 +748,35 @@ brasero_project_manager_iso (BraseroProjectManager *manager,
 
 BraseroProjectType
 brasero_project_manager_open_project (BraseroProjectManager *manager,
-				      const gchar *uri)
+				      const gchar *uri,
+				      gboolean playlist,
+				      gboolean burn)
 {
-	BraseroProjectType type;
 	GtkAction *action;
+	BraseroProjectType type;
 
-	gtk_widget_show (manager->priv->layout);
-	gtk_notebook_set_current_page (GTK_NOTEBOOK (manager), 1);
-	type = brasero_project_open_project (BRASERO_PROJECT (manager->priv->project), uri);
-
-	manager->priv->type = type;
-    	if (type == BRASERO_PROJECT_TYPE_INVALID) {
+	type = brasero_project_open_project (BRASERO_PROJECT (manager->priv->project), uri, playlist);
+	if (type == BRASERO_PROJECT_TYPE_INVALID) {
 		brasero_project_manager_switch (manager, BRASERO_PROJECT_TYPE_INVALID, NULL, NULL, TRUE);
-		return BRASERO_PROJECT_TYPE_INVALID;
+		return type;
 	}
 
-	if (type == BRASERO_PROJECT_TYPE_DATA)
-		brasero_layout_load (BRASERO_LAYOUT (manager->priv->layout), BRASERO_LAYOUT_DATA);
-	else
-		brasero_layout_load (BRASERO_LAYOUT (manager->priv->layout), BRASERO_LAYOUT_AUDIO);
+	brasero_project_manager_switch (manager,
+					type,
+					NULL,
+					NULL,
+					FALSE);
+
+	if (burn) {
+		brasero_project_burn (BRASERO_PROJECT (manager->priv->project));
+		return type;
+	}
 
 	action = gtk_action_group_get_action (manager->priv->action_group, "NewChoose");
 	gtk_action_set_sensitive (action, TRUE);
-
 	return type;
 }
 
-void
-brasero_project_manager_burn_project (BraseroProjectManager *manager,
-				      const gchar *uri)
-{
-	BraseroProjectType type;
-
-	brasero_project_manager_set_oneshot (manager, TRUE);
-	type = brasero_project_open_project (BRASERO_PROJECT (manager->priv->project), uri);
-	if (type == BRASERO_PROJECT_TYPE_INVALID)
-		return;
-
-	manager->priv->type = type;
-	brasero_project_burn (BRASERO_PROJECT (manager->priv->project));
-}
-
-#ifdef BUILD_PLAYLIST
-
-BraseroProjectType
-brasero_project_manager_open_playlist (BraseroProjectManager *manager,
-				       const gchar *uri)
-{
-	BraseroProjectType type;
-	GtkAction *action;
-
-    	gtk_widget_show (manager->priv->layout);
-	gtk_notebook_set_current_page (GTK_NOTEBOOK (manager), 1);
-	type = brasero_project_open_playlist (BRASERO_PROJECT (manager->priv->project), uri);
-	manager->priv->type = type;
-
-    	if (type == BRASERO_PROJECT_TYPE_INVALID) {
-		brasero_project_manager_switch (manager, BRASERO_PROJECT_TYPE_INVALID, NULL, NULL, TRUE);
-		return BRASERO_PROJECT_TYPE_INVALID;
-	}
-
-	brasero_layout_load (BRASERO_LAYOUT (manager->priv->layout), BRASERO_LAYOUT_AUDIO);
-	action = gtk_action_group_get_action (manager->priv->action_group, "NewChoose");
-	gtk_action_set_sensitive (action, TRUE);
-
-	return BRASERO_PROJECT_TYPE_AUDIO;
-}
-
-#endif
-
 BraseroProjectType
 brasero_project_manager_open_by_mime (BraseroProjectManager *manager,
 				      const gchar *uri,
@@ -988,7 +786,7 @@ brasero_project_manager_open_by_mime (BraseroProjectManager *manager,
 	 * installed, it's returned as application/xml, so check that too. */
 	if (!strcmp (mime, "application/x-brasero")
 	||  !strcmp (mime, "application/xml"))
-		return brasero_project_manager_open_project (manager, uri);
+		return brasero_project_manager_open_project (manager, uri, FALSE, FALSE);
 
 #ifdef BUILD_PLAYLIST
 
@@ -996,7 +794,9 @@ brasero_project_manager_open_by_mime (BraseroProjectManager *manager,
 	     ||  !strcmp (mime, "audio/x-ms-asx")
 	     ||  !strcmp (mime, "audio/x-mp3-playlist")
 	     ||  !strcmp (mime, "audio/x-mpegurl"))
-		return brasero_project_manager_open_playlist (manager, uri);
+		return brasero_project_manager_open_project (manager, uri, TRUE, FALSE);
+
+
 #endif
 
 	else if (!strcmp (mime, "application/x-cd-image")
@@ -1022,6 +822,9 @@ brasero_project_manager_open_uri (BraseroProjectManager *manager,
 	/* FIXME: make that asynchronous */
 	/* NOTE: don't follow symlink because we want to identify them */
 	file = g_file_new_for_commandline_arg (uri_arg);
+	if (!file)
+		return BRASERO_PROJECT_TYPE_INVALID;
+
 	info = g_file_query_info (file,
 				  G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE ","
 				  G_FILE_ATTRIBUTE_STANDARD_IS_SYMLINK ","
@@ -1030,6 +833,11 @@ brasero_project_manager_open_uri (BraseroProjectManager *manager,
 				  NULL,
 				  NULL);
 
+	if (!info) {
+		g_object_unref (file);
+		return BRASERO_PROJECT_TYPE_INVALID;
+	}
+
 	/* if that's a symlink, redo it on its target to get the real mime type
 	 * that usually also depends on the extension of the target:
 	 * ex: an iso file with the extension .iso will be seen as octet-stream
@@ -1084,8 +892,8 @@ brasero_project_manager_open_uri (BraseroProjectManager *manager,
 		gchar *string;
 
 		string = g_strdup_printf (_("The project \"%s\" does not exist"), uri);
-		brasero_app_alert (BRASERO_APP (gtk_widget_get_toplevel (GTK_WIDGET (manager))),
-				   _("Error while loading the project."),
+		brasero_app_alert (brasero_app_get_default (),
+				   _("Error while loading the project"),
 				   string,
 				   GTK_MESSAGE_ERROR);
 		g_free (string);
@@ -1107,7 +915,6 @@ brasero_project_manager_open_cb (GtkAction *action, BraseroProjectManager *manag
 	gint answer;
 	GtkWidget *chooser;
 	GtkWidget *toplevel;
-	BraseroProjectType type;
 
 	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (manager));
 	chooser = gtk_file_chooser_dialog_new (_("Open Project"),
@@ -1130,8 +937,7 @@ brasero_project_manager_open_cb (GtkAction *action, BraseroProjectManager *manag
 	uri = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (chooser));
 	gtk_widget_destroy (chooser);
 
-	manager->priv->oneshot = FALSE;
-	type = brasero_project_manager_open_uri (manager, uri);
+	brasero_project_manager_open_uri (manager, uri);
 	g_free (uri);
 }
 
@@ -1140,17 +946,9 @@ brasero_project_manager_recent_clicked_cb (BraseroProjectTypeChooser *chooser,
 					   const gchar *uri,
 					   BraseroProjectManager *manager)
 {
-	manager->priv->oneshot = FALSE;
 	brasero_project_manager_open_uri (manager, uri);
 }
 
-void
-brasero_project_manager_set_oneshot (BraseroProjectManager *manager,
-				     gboolean oneshot)
-{
-	manager->priv->oneshot = oneshot;
-}
-
 void
 brasero_project_manager_empty (BraseroProjectManager *manager)
 {
@@ -1186,6 +984,7 @@ brasero_project_manager_last_saved_clicked_cb (BraseroProjectTypeChooser *choose
 gboolean
 brasero_project_manager_save_session (BraseroProjectManager *manager,
 				      const gchar *path,
+				      gchar **saved_uri,
 				      gboolean cancellable)
 {
     	gboolean result = FALSE;
@@ -1199,6 +998,7 @@ brasero_project_manager_save_session (BraseroProjectManager *manager,
 		uri = g_filename_to_uri (path, NULL, NULL);
     		result = brasero_project_save_session (BRASERO_PROJECT (manager->priv->project),
 						       uri,
+						       saved_uri,
 						       cancellable);
 		g_free (uri);
 	}
@@ -1350,14 +1150,10 @@ brasero_project_manager_finalize (GObject *object)
 
 	cobj = BRASERO_PROJECT_MANAGER (object);
 
-	if (cobj->priv->io) {
-		brasero_io_cancel_by_base (cobj->priv->io, cobj->priv->size_preview);
-
+	if (cobj->priv->size_preview) {
+		brasero_io_cancel_by_base (cobj->priv->size_preview);
 		g_free (cobj->priv->size_preview);
 		cobj->priv->size_preview = NULL;
-
-		g_object_unref (cobj->priv->io);
-		cobj->priv->io = NULL;
 	}
 
 	if (cobj->priv->preview_id) {
